@@ -20,6 +20,8 @@ var namespacemembers_dup =
     [ "r", "namespacemembers_0x72.html", null ],
     [ "s", "namespacemembers_0x73.html", null ],
     [ "t", "namespacemembers_0x74.html", null ],
+    [ "u", "namespacemembers_0x75.html", null ],
+    [ "v", "namespacemembers_0x76.html", null ],
     [ "w", "namespacemembers_0x77.html", null ],
     [ "~", "namespacemembers_0x7e.html", null ]
 ];
\ No newline at end of file
