@@ -1,20 +1,54 @@
 var NAVTREEINDEX107 =
 {
-"functions_prop_0x79.html":[1,3,4,25],
-"functions_prop_0x7a.html":[1,3,4,26],
+"functions_func_0x74.html":[1,3,1,19],
+"functions_func_0x75.html":[1,3,1,20],
+"functions_func_0x76.html":[1,3,1,21],
+"functions_func_0x77.html":[1,3,1,22],
+"functions_func_0x78.html":[1,3,1,23],
+"functions_func_0x79.html":[1,3,1,24],
+"functions_func_0x7a.html":[1,3,1,25],
+"functions_prop.html":[1,3,5],
+"functions_prop.html":[1,3,5,0],
+"functions_prop_0x61.html":[1,3,5,1],
+"functions_prop_0x62.html":[1,3,5,2],
+"functions_prop_0x63.html":[1,3,5,3],
+"functions_prop_0x64.html":[1,3,5,4],
+"functions_prop_0x65.html":[1,3,5,5],
+"functions_prop_0x66.html":[1,3,5,6],
+"functions_prop_0x67.html":[1,3,5,7],
+"functions_prop_0x68.html":[1,3,5,8],
+"functions_prop_0x69.html":[1,3,5,9],
+"functions_prop_0x6a.html":[1,3,5,10],
+"functions_prop_0x6b.html":[1,3,5,11],
+"functions_prop_0x6c.html":[1,3,5,12],
+"functions_prop_0x6d.html":[1,3,5,13],
+"functions_prop_0x6e.html":[1,3,5,14],
+"functions_prop_0x6f.html":[1,3,5,15],
+"functions_prop_0x70.html":[1,3,5,16],
+"functions_prop_0x71.html":[1,3,5,17],
+"functions_prop_0x72.html":[1,3,5,18],
+"functions_prop_0x73.html":[1,3,5,19],
+"functions_prop_0x74.html":[1,3,5,20],
+"functions_prop_0x75.html":[1,3,5,21],
+"functions_prop_0x76.html":[1,3,5,22],
+"functions_prop_0x77.html":[1,3,5,23],
+"functions_prop_0x78.html":[1,3,5,24],
+"functions_prop_0x79.html":[1,3,5,25],
+"functions_prop_0x7a.html":[1,3,5,26],
 "functions_vars.html":[1,3,2],
 "functions_vars.html":[1,3,2,0],
 "functions_vars_0x65.html":[1,3,2,1],
 "functions_vars_0x69.html":[1,3,2,2],
+"functions_vars_0x74.html":[1,3,2,3],
 "hierarchy.html":[1,2],
 "index.html":[],
 "interface_i_q_abstract_message_handler_signals.html":[1,0,14],
 "interface_i_q_abstract_uri_resolver_signals.html":[1,0,15],
 "interface_qt_core_1_1_i_q_abstract_animation_signals.html":[1,0,3,138],
 "interface_qt_core_1_1_i_q_abstract_animation_signals.html#a1c47d5ebb987841e6313a0c1efae8a51":[1,0,3,138,0],
+"interface_qt_core_1_1_i_q_abstract_animation_signals.html#a1c68e62846458b07aeaf4e776f50bda8":[1,0,3,138,1],
 "interface_qt_core_1_1_i_q_abstract_animation_signals.html#a20715d73ecdc1fd724e8265b5d4bfa16":[1,0,3,138,3],
 "interface_qt_core_1_1_i_q_abstract_animation_signals.html#a9183e72716cd1afc112a22eaef277f08":[1,0,3,138,2],
-"interface_qt_core_1_1_i_q_abstract_animation_signals.html#ad2ad49edce3c0784b4ed46c40f55b68d":[1,0,3,138,1],
 "interface_qt_core_1_1_i_q_abstract_event_dispatcher_signals.html":[1,0,3,139],
 "interface_qt_core_1_1_i_q_abstract_event_dispatcher_signals.html#aeefa2bc6c9b19e9b3a38579e45fc10fc":[1,0,3,139,0],
 "interface_qt_core_1_1_i_q_abstract_event_dispatcher_signals.html#afb1d8b14f295f630bbe529ed339f47fa":[1,0,3,139,1],
@@ -80,7 +114,7 @@ var NAVTREEINDEX107 =
 "interface_qt_core_1_1_i_q_object_cleanup_handler_signals.html":[1,0,3,159],
 "interface_qt_core_1_1_i_q_object_signals.html":[1,0,3,158],
 "interface_qt_core_1_1_i_q_object_signals.html#a896c638d36cc5a126312913abe4598cf":[1,0,3,158,1],
-"interface_qt_core_1_1_i_q_object_signals.html#aa3cfa8685d2cfe92ed627457df715625":[1,0,3,158,0],
+"interface_qt_core_1_1_i_q_object_signals.html#abb26700bc4836d6d7b0641cfe425ba2f":[1,0,3,158,0],
 "interface_qt_core_1_1_i_q_parallel_animation_group_signals.html":[1,0,3,160],
 "interface_qt_core_1_1_i_q_pause_animation_signals.html":[1,0,3,161],
 "interface_qt_core_1_1_i_q_plugin_loader_signals.html":[1,0,3,162],
@@ -100,10 +134,10 @@ var NAVTREEINDEX107 =
 "interface_qt_core_1_1_i_q_shared_data.html#a6244f22fc6d3a13827e1486801e99d96":[1,0,3,135,0],
 "interface_qt_core_1_1_i_q_shared_memory_signals.html":[1,0,3,167],
 "interface_qt_core_1_1_i_q_signal_mapper_signals.html":[1,0,3,168],
-"interface_qt_core_1_1_i_q_signal_mapper_signals.html#a2c66125f3fb4b8b2eecce8c9cad1c072":[1,0,3,168,3],
+"interface_qt_core_1_1_i_q_signal_mapper_signals.html#a01c009f3e4a628314f9fd8e48b81a76c":[1,0,3,168,3],
+"interface_qt_core_1_1_i_q_signal_mapper_signals.html#a60f56dde517c927765463bc2b16a34bf":[1,0,3,168,1],
+"interface_qt_core_1_1_i_q_signal_mapper_signals.html#a755e846f91abb096698f75820fbc5c51":[1,0,3,168,0],
 "interface_qt_core_1_1_i_q_signal_mapper_signals.html#a7e386b7bb249dcb852b2240ebc61a348":[1,0,3,168,2],
-"interface_qt_core_1_1_i_q_signal_mapper_signals.html#ac23484ce8694257776ff9c104167b628":[1,0,3,168,0],
-"interface_qt_core_1_1_i_q_signal_mapper_signals.html#aeab0f8ea0e7d97e13b2dd7ceae95257b":[1,0,3,168,1],
 "interface_qt_core_1_1_i_q_signal_transition_signals.html":[1,0,3,169],
 "interface_qt_core_1_1_i_q_socket_notifier_signals.html":[1,0,3,170],
 "interface_qt_core_1_1_i_q_socket_notifier_signals.html#ab5faf3585b1d7c3e035e54f06948201e":[1,0,3,170,0],
@@ -118,9 +152,9 @@ var NAVTREEINDEX107 =
 "interface_qt_core_1_1_i_q_text_codec_factory_interface.html#a1655f2a369f799dd65b959d09f1b184d":[1,0,3,136,0],
 "interface_qt_core_1_1_i_q_text_codec_plugin_signals.html":[1,0,3,174],
 "interface_qt_core_1_1_i_q_time_line_signals.html":[1,0,3,175],
+"interface_qt_core_1_1_i_q_time_line_signals.html#a3cdfe51ac104c81a1a8c64cac54efa92":[1,0,3,175,1],
 "interface_qt_core_1_1_i_q_time_line_signals.html#a81cf5b1ab3fcc36a5605cc896e2ad1f3":[1,0,3,175,3],
 "interface_qt_core_1_1_i_q_time_line_signals.html#a9683218fd42bfeaa24d636d200a0ca89":[1,0,3,175,2],
-"interface_qt_core_1_1_i_q_time_line_signals.html#a9f871d31fdb130e86b550f38113cdaf5":[1,0,3,175,1],
 "interface_qt_core_1_1_i_q_time_line_signals.html#af201d22ba85c4c8d021180c71a16d37c":[1,0,3,175,0],
 "interface_qt_core_1_1_i_q_timer_signals.html":[1,0,3,176],
 "interface_qt_core_1_1_i_q_timer_signals.html#ac109b8394756a36c01aeba7378acfee3":[1,0,3,176,0],
@@ -135,8 +169,8 @@ var NAVTREEINDEX107 =
 "interface_qt_gui_1_1_i_q_abstract_button_signals.html#ad67efb10f8118f8a32897f79f9122377":[1,0,4,372,4],
 "interface_qt_gui_1_1_i_q_abstract_item_delegate_signals.html":[1,0,4,373],
 "interface_qt_gui_1_1_i_q_abstract_item_delegate_signals.html#a036805d03ae9d4ef665dfc758a41747c":[1,0,4,373,0],
-"interface_qt_gui_1_1_i_q_abstract_item_delegate_signals.html#a65d8a999e118c3ca1e3b6692388440f8":[1,0,4,373,3],
 "interface_qt_gui_1_1_i_q_abstract_item_delegate_signals.html#a7ddcbd83e9683b51e338118aa50ae28a":[1,0,4,373,2],
+"interface_qt_gui_1_1_i_q_abstract_item_delegate_signals.html#a93b91db9911d89915541abd9cabb9b57":[1,0,4,373,3],
 "interface_qt_gui_1_1_i_q_abstract_item_delegate_signals.html#ac02cd12da61753245c3be58d17a0dfdc":[1,0,4,373,1],
 "interface_qt_gui_1_1_i_q_abstract_item_view_signals.html":[1,0,4,374],
 "interface_qt_gui_1_1_i_q_abstract_item_view_signals.html#a764353bfda39dcde5798001da5339f8a":[1,0,4,374,1],
@@ -165,16 +199,16 @@ var NAVTREEINDEX107 =
 "interface_qt_gui_1_1_i_q_abstract_text_document_layout_signals.html#abfe8a8348bdfab1c691b5a44ed89903a":[1,0,4,381,3],
 "interface_qt_gui_1_1_i_q_abstract_text_document_layout_signals.html#afbd4958eb78967b98973f785f8a0223d":[1,0,4,381,0],
 "interface_qt_gui_1_1_i_q_action_group_signals.html":[1,0,4,383],
-"interface_qt_gui_1_1_i_q_action_group_signals.html#a0f17ce69f6ee9620e926042a813b50c6":[1,0,4,383,1],
-"interface_qt_gui_1_1_i_q_action_group_signals.html#a10afb64fd0328f43caee4c4008fb371f":[1,0,4,383,0],
-"interface_qt_gui_1_1_i_q_action_group_signals.html#a2885622ef5ab7f69e3801e98191de11f":[1,0,4,383,2],
+"interface_qt_gui_1_1_i_q_action_group_signals.html#a535b56de55d7b6dc88e3d66510e10483":[1,0,4,383,1],
+"interface_qt_gui_1_1_i_q_action_group_signals.html#ab9faf6a6af1af6c3279510728efeb054":[1,0,4,383,0],
+"interface_qt_gui_1_1_i_q_action_group_signals.html#aefcc6550d243c6b0588aa0d1ed50140a":[1,0,4,383,2],
 "interface_qt_gui_1_1_i_q_action_signals.html":[1,0,4,382],
 "interface_qt_gui_1_1_i_q_action_signals.html#a1dc96244113cda16ec702932df79730c":[1,0,4,382,2],
+"interface_qt_gui_1_1_i_q_action_signals.html#a48206174f68ec3524d19002dc891b6fe":[1,0,4,382,4],
 "interface_qt_gui_1_1_i_q_action_signals.html#a4ab29c7bb5d24695b2fca377bd94bb60":[1,0,4,382,0],
 "interface_qt_gui_1_1_i_q_action_signals.html#a513e64f9172fea8262b02b36d418452b":[1,0,4,382,1],
 "interface_qt_gui_1_1_i_q_action_signals.html#a5bd9528e9f3a28f524de85cbbc00d419":[1,0,4,382,6],
 "interface_qt_gui_1_1_i_q_action_signals.html#a711afcd4a094b28860734471f85c0e39":[1,0,4,382,5],
-"interface_qt_gui_1_1_i_q_action_signals.html#a89e76c3e16273b95e92bac772c9d019f":[1,0,4,382,4],
 "interface_qt_gui_1_1_i_q_action_signals.html#a9de8e0530b0b4170d8e35c55f52b9b3f":[1,0,4,382,3],
 "interface_qt_gui_1_1_i_q_application_signals.html":[1,0,4,384],
 "interface_qt_gui_1_1_i_q_application_signals.html#a1ba2065bde4a41b66d25f5130f551820":[1,0,4,384,4],
@@ -184,19 +218,19 @@ var NAVTREEINDEX107 =
 "interface_qt_gui_1_1_i_q_application_signals.html#acb57c3a3db5f9ecc93992229462270aa":[1,0,4,384,1],
 "interface_qt_gui_1_1_i_q_box_layout_signals.html":[1,0,4,385],
 "interface_qt_gui_1_1_i_q_button_group_signals.html":[1,0,4,386],
-"interface_qt_gui_1_1_i_q_button_group_signals.html#a5b16595d2de6c09226ad8ce91fa2cf1b":[1,0,4,386,2],
-"interface_qt_gui_1_1_i_q_button_group_signals.html#a6a263d13021f6b0f5a9938ca88ded8c5":[1,0,4,386,5],
-"interface_qt_gui_1_1_i_q_button_group_signals.html#ab93742eb0af50ca45dc2b7fb8f487f2c":[1,0,4,386,0],
-"interface_qt_gui_1_1_i_q_button_group_signals.html#adff666ae1123827921ccd310d8668bfc":[1,0,4,386,1],
-"interface_qt_gui_1_1_i_q_button_group_signals.html#ae375e29b0dd2185f56efd426c4ca7a81":[1,0,4,386,3],
-"interface_qt_gui_1_1_i_q_button_group_signals.html#af87bace889dee07b4be026889288b82f":[1,0,4,386,4],
+"interface_qt_gui_1_1_i_q_button_group_signals.html#a0b4fc9caf0ba2649e678f7f4db84a951":[1,0,4,386,4],
+"interface_qt_gui_1_1_i_q_button_group_signals.html#a4953d3fa27ad5a09200c7b90785270bc":[1,0,4,386,1],
+"interface_qt_gui_1_1_i_q_button_group_signals.html#a6e102e20f43c67b29dbbe2e90b1283c2":[1,0,4,386,3],
+"interface_qt_gui_1_1_i_q_button_group_signals.html#a714ecb4462ae0f77c8ee08e4213f5b8d":[1,0,4,386,5],
+"interface_qt_gui_1_1_i_q_button_group_signals.html#ab2cafa261ff6a47571f57e0e39be5272":[1,0,4,386,2],
+"interface_qt_gui_1_1_i_q_button_group_signals.html#add602a5b9c4624a83686b57cccc1eed4":[1,0,4,386,0],
 "interface_qt_gui_1_1_i_q_calendar_widget_signals.html":[1,0,4,387],
 "interface_qt_gui_1_1_i_q_calendar_widget_signals.html#a22978bf5f730f2bc50d5fc47c938c472":[1,0,4,387,1],
 "interface_qt_gui_1_1_i_q_calendar_widget_signals.html#a42e4a1ee7587ec2da589135e2fe2000f":[1,0,4,387,3],
 "interface_qt_gui_1_1_i_q_calendar_widget_signals.html#a65f3612ecbe0c6f3d6cf06dc54b07900":[1,0,4,387,2],
 "interface_qt_gui_1_1_i_q_calendar_widget_signals.html#ac629708e899791e7e99ebf9c0977d491":[1,0,4,387,0],
 "interface_qt_gui_1_1_i_q_check_box_signals.html":[1,0,4,388],
-"interface_qt_gui_1_1_i_q_check_box_signals.html#a1264d718a97a33f70811e6469a28338d":[1,0,4,388,0],
+"interface_qt_gui_1_1_i_q_check_box_signals.html#a39a3b4a60057786dfbe33448618eb5b2":[1,0,4,388,0],
 "interface_qt_gui_1_1_i_q_clipboard_signals.html":[1,0,4,389],
 "interface_qt_gui_1_1_i_q_clipboard_signals.html#a429c760d2830fbc119518e47f486236f":[1,0,4,389,1],
 "interface_qt_gui_1_1_i_q_clipboard_signals.html#abbcd3b9afa75bd7ac100feb9f9998014":[1,0,4,389,3],
@@ -210,44 +244,10 @@ var NAVTREEINDEX107 =
 "interface_qt_gui_1_1_i_q_combo_box_signals.html":[1,0,4,392],
 "interface_qt_gui_1_1_i_q_combo_box_signals.html#a0fd0ffdd623b91eccb23919c1bfece87":[1,0,4,392,5],
 "interface_qt_gui_1_1_i_q_combo_box_signals.html#a18e23c27b4d0f4b24032b9c0b5882ea2":[1,0,4,392,0],
-"interface_qt_gui_1_1_i_q_combo_box_signals.html#a2a3689ebb7c08f563714723e60594440":[1,0,4,392,4],
+"interface_qt_gui_1_1_i_q_combo_box_signals.html#a3a68f9c9efe05d27b7d46b5c28c7ebfa":[1,0,4,392,3],
 "interface_qt_gui_1_1_i_q_combo_box_signals.html#a3b1b9175cb2d5597b9260675babdb504":[1,0,4,392,2],
-"interface_qt_gui_1_1_i_q_combo_box_signals.html#a46c90860d26127d0db08e5bbe52e9bb0":[1,0,4,392,6],
-"interface_qt_gui_1_1_i_q_combo_box_signals.html#a5c7fb1f04724892b75370befc8677ec4":[1,0,4,392,3],
+"interface_qt_gui_1_1_i_q_combo_box_signals.html#a4b744ffaa724e41925da8afe49d48b8a":[1,0,4,392,4],
+"interface_qt_gui_1_1_i_q_combo_box_signals.html#a4b83b233415c03f475669ca4e6b78ee2":[1,0,4,392,6],
 "interface_qt_gui_1_1_i_q_combo_box_signals.html#a86119ec6fbc534ff0b1542aa8c386ea3":[1,0,4,392,7],
-"interface_qt_gui_1_1_i_q_combo_box_signals.html#ac26facf1e54ffece3cdbfdec25fd29e4":[1,0,4,392,1],
-"interface_qt_gui_1_1_i_q_command_link_button_signals.html":[1,0,4,393],
-"interface_qt_gui_1_1_i_q_common_style_signals.html":[1,0,4,394],
-"interface_qt_gui_1_1_i_q_completer_signals.html":[1,0,4,395],
-"interface_qt_gui_1_1_i_q_completer_signals.html#a373ef73487db1eccb33b86d417ebdbfe":[1,0,4,395,2],
-"interface_qt_gui_1_1_i_q_completer_signals.html#a9cc27233407180ea09bbc4881d35cfef":[1,0,4,395,0],
-"interface_qt_gui_1_1_i_q_completer_signals.html#abbb232e7a3430f9517a8d4775db8eb39":[1,0,4,395,1],
-"interface_qt_gui_1_1_i_q_completer_signals.html#ac53f2da9172e98b4575336c4dc6a8e78":[1,0,4,395,3],
-"interface_qt_gui_1_1_i_q_data_widget_mapper_signals.html":[1,0,4,396],
-"interface_qt_gui_1_1_i_q_data_widget_mapper_signals.html#a9bfd37483ea98a6b885b52e9fb6c7808":[1,0,4,396,0],
-"interface_qt_gui_1_1_i_q_date_edit_signals.html":[1,0,4,397],
-"interface_qt_gui_1_1_i_q_date_time_edit_signals.html":[1,0,4,398],
-"interface_qt_gui_1_1_i_q_date_time_edit_signals.html#a154b3066a4ac05909c071d167769c7fa":[1,0,4,398,1],
-"interface_qt_gui_1_1_i_q_date_time_edit_signals.html#a3f91f4d68ade0dcba339ffae1be4d854":[1,0,4,398,0],
-"interface_qt_gui_1_1_i_q_date_time_edit_signals.html#acdb2449e027952deef30de488f85baab":[1,0,4,398,2],
-"interface_qt_gui_1_1_i_q_desktop_widget_signals.html":[1,0,4,399],
-"interface_qt_gui_1_1_i_q_desktop_widget_signals.html#a3d1eb4dd5097a3ffee2df923400e2601":[1,0,4,399,0],
-"interface_qt_gui_1_1_i_q_desktop_widget_signals.html#aa628f214e26b9e0fe7c7c2d6e7ba1b9d":[1,0,4,399,1],
-"interface_qt_gui_1_1_i_q_desktop_widget_signals.html#abf2064d8ccd3379a05d12a5cc3894995":[1,0,4,399,2],
-"interface_qt_gui_1_1_i_q_dial_signals.html":[1,0,4,400],
-"interface_qt_gui_1_1_i_q_dial_signals.html#a29f39ca942b2937d78cae7e394c4eae4":[1,0,4,400,0],
-"interface_qt_gui_1_1_i_q_dial_signals.html#ad6f6a1f73aa7e6e6036859871cc4d514":[1,0,4,400,1],
-"interface_qt_gui_1_1_i_q_dial_signals.html#afeac54b875c68f9b4480d10f3b251ecf":[1,0,4,400,2],
-"interface_qt_gui_1_1_i_q_dialog_button_box_signals.html":[1,0,4,402],
-"interface_qt_gui_1_1_i_q_dialog_button_box_signals.html#a8ebf007852ffc3ae46e1c08b9c28a757":[1,0,4,402,2],
-"interface_qt_gui_1_1_i_q_dialog_button_box_signals.html#aa85f52ca456d8cdae689b21ac2ad6320":[1,0,4,402,0],
-"interface_qt_gui_1_1_i_q_dialog_button_box_signals.html#ab690d8e44effbf4936a8c3f5015d1d27":[1,0,4,402,1],
-"interface_qt_gui_1_1_i_q_dialog_button_box_signals.html#af289096d6e39705e220c6ab181774861":[1,0,4,402,3],
-"interface_qt_gui_1_1_i_q_dialog_signals.html":[1,0,4,401],
-"interface_qt_gui_1_1_i_q_dialog_signals.html#a7432bc342d6faddf92d058040628439d":[1,0,4,401,2],
-"interface_qt_gui_1_1_i_q_dialog_signals.html#ab48d99fe05cb706caa7ca6824115998f":[1,0,4,401,0],
-"interface_qt_gui_1_1_i_q_dialog_signals.html#aed8c77c786b834f2b60218661c73b48d":[1,0,4,401,1],
-"interface_qt_gui_1_1_i_q_dir_model_signals.html":[1,0,4,403],
-"interface_qt_gui_1_1_i_q_dock_widget_signals.html":[1,0,4,404],
-"interface_qt_gui_1_1_i_q_dock_widget_signals.html#a230ce87b0fb1d3206bb004b5ed1e6401":[1,0,4,404,0]
+"interface_qt_gui_1_1_i_q_combo_box_signals.html#a9aaf8dc1c93a3ab70734a1d467c942f2":[1,0,4,392,1]
 };
