@@ -1,5 +1,39 @@
 var NAVTREEINDEX109 =
 {
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a0ad6c12d221f40ea48d50460ad21ce9d":[1,0,4,363,18],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a10ee0efc9f329b2bc0d57d650cf0d7f2":[1,0,4,363,3],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a180f218f4dd5a7a38f55e73b77529f47":[1,0,4,363,21],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a2594fcb33d57fbf6d453aebf05717f3c":[1,0,4,363,16],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a36947efc1998182eb19fdde16e2e04b7":[1,0,4,363,12],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a382b53c1827be1e56c995265498df886":[1,0,4,363,2],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a41ab90b45e767f5934201f3831e8672c":[1,0,4,363,22],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a48e0dd2777333b9f2213bf6f30e8354b":[1,0,4,363,20],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a4932533452edf88175a19cb8337d0131":[1,0,4,363,15],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a51309348da6e71134bec45b080043c43":[1,0,4,363,11],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a57712478887916fba6992e542f42a565":[1,0,4,363,14],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a65fe91cd4b7a5500974d958331af100f":[1,0,4,363,17],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a66b152d1da52e4a48b8c01f1f02b2c2b":[1,0,4,363,8],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a6d3fa32a59ace9201fa898d7936c4108":[1,0,4,363,9],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a6ddb48a3f95c5c12361a7b22dd97500e":[1,0,4,363,23],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a6e0dfc4eec3f9db9a67d08d915a41212":[1,0,4,363,5],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a6fb6affb00380a2c3ba77e2726a26b40":[1,0,4,363,6],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#a7af8941b2ba8a0042fc4c0df574a09bb":[1,0,4,363,10],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#aae3472a6b9b78213dee0484a88c9f129":[1,0,4,363,0],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#aba49971b35f0c1410323c4375966db65":[1,0,4,363,4],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#ac44bcfa4d8911951c47162c3941ba085":[1,0,4,363,1],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#ac6e0e103a017b0a8a25646b12a433226":[1,0,4,363,7],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#adb1b4be2a620fbc7f3239c80ede66934":[1,0,4,363,13],
+"interface_qt_gui_1_1_i_q_graphics_layout_item.html#afc0a9336cf70b1fa4fd7cf1a452d1bbc":[1,0,4,363,19],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html":[1,0,4,423],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#a0221da0dc41259e25eca7d5722a959b1":[1,0,4,423,3],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#a079e9e790e2f1124e06c90da35e81b97":[1,0,4,423,8],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#a3c36a39e4f7ca1a1a0d6b4e98afc8f12":[1,0,4,423,10],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#a51c6a0bb70b7c2d81ad2f0549ef91c53":[1,0,4,423,2],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#a55652e1691042a10ec0f027d2a90dfb1":[1,0,4,423,4],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#a97086b231bb139b021c2924e4928c1e5":[1,0,4,423,7],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#a9797f6aab603ae3637b99f07f2f1f268":[1,0,4,423,5],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#aaabe1f96b4ad741af0800af26ff68bff":[1,0,4,423,6],
+"interface_qt_gui_1_1_i_q_graphics_object_signals.html#ac446f01906df34b905843a90ddf14b1a":[1,0,4,423,9],
 "interface_qt_gui_1_1_i_q_graphics_object_signals.html#acc6f1e08d21ee5de231ab17e8710b95e":[1,0,4,423,0],
 "interface_qt_gui_1_1_i_q_graphics_object_signals.html#ae3025da70453bc8223990f6dc7d4580a":[1,0,4,423,11],
 "interface_qt_gui_1_1_i_q_graphics_object_signals.html#af04094130767d2baf09889e0c418e596":[1,0,4,423,1],
@@ -22,8 +56,8 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_graphics_scene_signals.html#a82f3b8236e9441a2a251794955b10104":[1,0,4,428,2],
 "interface_qt_gui_1_1_i_q_graphics_scene_signals.html#ac65e16778f00e5ae84e65556ddae36b4":[1,0,4,428,0],
 "interface_qt_gui_1_1_i_q_graphics_text_item_signals.html":[1,0,4,429],
-"interface_qt_gui_1_1_i_q_graphics_text_item_signals.html#a1390e155475201fffd548c36508eb4be":[1,0,4,429,1],
-"interface_qt_gui_1_1_i_q_graphics_text_item_signals.html#a50d110727b1740af832a866e7fc6e6cc":[1,0,4,429,0],
+"interface_qt_gui_1_1_i_q_graphics_text_item_signals.html#abf77300a6a0fef2a28eca54ad57e513a":[1,0,4,429,1],
+"interface_qt_gui_1_1_i_q_graphics_text_item_signals.html#aced30568d9441e1d2654e68293497110":[1,0,4,429,0],
 "interface_qt_gui_1_1_i_q_graphics_transform_signals.html":[1,0,4,430],
 "interface_qt_gui_1_1_i_q_graphics_view_signals.html":[1,0,4,431],
 "interface_qt_gui_1_1_i_q_graphics_widget_signals.html":[1,0,4,432],
@@ -31,8 +65,8 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_graphics_widget_signals.html#afde6ed02b25a86719013d0b622219413":[1,0,4,432,1],
 "interface_qt_gui_1_1_i_q_grid_layout_signals.html":[1,0,4,433],
 "interface_qt_gui_1_1_i_q_group_box_signals.html":[1,0,4,434],
-"interface_qt_gui_1_1_i_q_group_box_signals.html#a509256e8974d7031a52062438b7e8b6d":[1,0,4,434,2],
 "interface_qt_gui_1_1_i_q_group_box_signals.html#a654f24009ccddae2060017c7bce91e89":[1,0,4,434,0],
+"interface_qt_gui_1_1_i_q_group_box_signals.html#ab0231de4bd76d945866bce4ca2d5efd3":[1,0,4,434,2],
 "interface_qt_gui_1_1_i_q_group_box_signals.html#ad626edd7ffe981858cd011d6464be365":[1,0,4,434,1],
 "interface_qt_gui_1_1_i_q_h_box_layout_signals.html":[1,0,4,435],
 "interface_qt_gui_1_1_i_q_header_view_signals.html":[1,0,4,436],
@@ -103,12 +137,12 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_layout_signals.html":[1,0,4,449],
 "interface_qt_gui_1_1_i_q_line_edit_signals.html":[1,0,4,450],
 "interface_qt_gui_1_1_i_q_line_edit_signals.html#a2bad2648269e86495705797407643fc4":[1,0,4,450,2],
+"interface_qt_gui_1_1_i_q_line_edit_signals.html#a5ba6fd19dc11440902b747d03ab0e3f3":[1,0,4,450,0],
 "interface_qt_gui_1_1_i_q_line_edit_signals.html#a64b280f48ad2d55798efda6c95cc7b9f":[1,0,4,450,3],
-"interface_qt_gui_1_1_i_q_line_edit_signals.html#a9b25751a2e8bf302f2d990fbcff59994":[1,0,4,450,0],
+"interface_qt_gui_1_1_i_q_line_edit_signals.html#a991380d909f0dcf351c790a2a19f7d97":[1,0,4,450,6],
 "interface_qt_gui_1_1_i_q_line_edit_signals.html#a9c451f618016cfb016e3fb01c8e7c226":[1,0,4,450,4],
-"interface_qt_gui_1_1_i_q_line_edit_signals.html#ab76fb840dad55db4b80ecd22a8e1c8a0":[1,0,4,450,5],
 "interface_qt_gui_1_1_i_q_line_edit_signals.html#ad8b6bd753223918c87e3d5daea69ebe7":[1,0,4,450,1],
-"interface_qt_gui_1_1_i_q_line_edit_signals.html#ae9cdca608c9f2e50e116a70aa0b20598":[1,0,4,450,6],
+"interface_qt_gui_1_1_i_q_line_edit_signals.html#af95da91f89ceb3fe6d7345c1b462c3a1":[1,0,4,450,5],
 "interface_qt_gui_1_1_i_q_list_view_signals.html":[1,0,4,451],
 "interface_qt_gui_1_1_i_q_list_view_signals.html#abf3c8f42a291c03896030ded5636f813":[1,0,4,451,0],
 "interface_qt_gui_1_1_i_q_list_widget_signals.html":[1,0,4,452],
@@ -126,7 +160,7 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_main_window_signals.html#a61324b584355c4f0a1cee2a5c4e77726":[1,0,4,453,1],
 "interface_qt_gui_1_1_i_q_main_window_signals.html#aab4d77d69456508a3e87734425c4093b":[1,0,4,453,0],
 "interface_qt_gui_1_1_i_q_mdi_area_signals.html":[1,0,4,454],
-"interface_qt_gui_1_1_i_q_mdi_area_signals.html#aa32c46c4ef0781d90f1d2078b1c8e9c3":[1,0,4,454,0],
+"interface_qt_gui_1_1_i_q_mdi_area_signals.html#ad0f355c38717f97d18ff04c8bca1181d":[1,0,4,454,0],
 "interface_qt_gui_1_1_i_q_mdi_sub_window_signals.html":[1,0,4,455],
 "interface_qt_gui_1_1_i_q_mdi_sub_window_signals.html#a8dfcd8894e766060626c113d0cfbcf06":[1,0,4,455,1],
 "interface_qt_gui_1_1_i_q_mdi_sub_window_signals.html#ae6ecb3c8d65bd2547a932b7013a0b2ad":[1,0,4,455,0],
@@ -159,14 +193,15 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_movie_signals.html#ad62ee46f7d243a865eaafe686f54709e":[1,0,4,460,0],
 "interface_qt_gui_1_1_i_q_page_setup_dialog_signals.html":[1,0,4,461],
 "interface_qt_gui_1_1_i_q_paint_device.html":[1,0,4,371],
+"interface_qt_gui_1_1_i_q_paint_device.html#a0af15dbccd3204367d232b8e4a570c86":[1,0,4,371,0],
 "interface_qt_gui_1_1_i_q_paint_device.html#a2ff0a6f90aac8fcc4b96187a9123c453":[1,0,4,371,14],
 "interface_qt_gui_1_1_i_q_paint_device.html#a5581582c36cd86b770b7ab484ec19350":[1,0,4,371,6],
 "interface_qt_gui_1_1_i_q_paint_device.html#a5e834024e015480e433b8ef744e25311":[1,0,4,371,7],
-"interface_qt_gui_1_1_i_q_paint_device.html#a62a3c34eed4149dc71ad3d2d9cdda46f":[1,0,4,371,0],
-"interface_qt_gui_1_1_i_q_paint_device.html#a66a8f2e3267f7453319a0020f8f242d3":[1,0,4,371,2],
-"interface_qt_gui_1_1_i_q_paint_device.html#a783cc40847599337cb5e1ec63c521931":[1,0,4,371,3],
+"interface_qt_gui_1_1_i_q_paint_device.html#a62a3c34eed4149dc71ad3d2d9cdda46f":[1,0,4,371,1],
+"interface_qt_gui_1_1_i_q_paint_device.html#a66a8f2e3267f7453319a0020f8f242d3":[1,0,4,371,3],
+"interface_qt_gui_1_1_i_q_paint_device.html#a783cc40847599337cb5e1ec63c521931":[1,0,4,371,4],
 "interface_qt_gui_1_1_i_q_paint_device.html#a7d557e24f6055480460bb1b44987aa2f":[1,0,4,371,8],
-"interface_qt_gui_1_1_i_q_paint_device.html#a82b18e3d883f4ed908b754cb032a3df0":[1,0,4,371,1],
+"interface_qt_gui_1_1_i_q_paint_device.html#a82b18e3d883f4ed908b754cb032a3df0":[1,0,4,371,2],
 "interface_qt_gui_1_1_i_q_paint_device.html#a87fc60b066cec45c018dc48e84deba97":[1,0,4,371,9],
 "interface_qt_gui_1_1_i_q_paint_device.html#a9119e04ac9afc827be72f9b9da9c60c7":[1,0,4,371,5],
 "interface_qt_gui_1_1_i_q_paint_device.html#a98b2af7ba40843b4834902e70d45c6bd":[1,0,4,371,10],
@@ -174,7 +209,6 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_paint_device.html#ad762a6acea7d0c543403f6d69fed1363":[1,0,4,371,11],
 "interface_qt_gui_1_1_i_q_paint_device.html#adee56c79e08e7d0d3526f91467e66dad":[1,0,4,371,13],
 "interface_qt_gui_1_1_i_q_paint_device.html#af0a35def2c4786d8dfc88e97163f9333":[1,0,4,371,12],
-"interface_qt_gui_1_1_i_q_paint_device.html#af97ade3df39256c79b26bf9640a79632":[1,0,4,371,4],
 "interface_qt_gui_1_1_i_q_pan_gesture_signals.html":[1,0,4,462],
 "interface_qt_gui_1_1_i_q_picture_format_interface.html":[1,0,4,369],
 "interface_qt_gui_1_1_i_q_picture_format_interface.html#a1652724c6a4ba5db2dcee268786417c6":[1,0,4,369,2],
@@ -186,12 +220,12 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html":[1,0,4,466],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#a1176a392ec29c9dfb237e66ceeccd702":[1,0,4,466,0],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#a1d00129f731abf653a5872c648b84fb6":[1,0,4,466,8],
+"interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#a33b6603d3e67374ed7c7fe7411167019":[1,0,4,466,3],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#a60d8b490f177690e0762e8bf2af9d48d":[1,0,4,466,5],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#a7f55f1d8998312a8eeee29f1640c32fe":[1,0,4,466,4],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#aa5bb5a6f9cad3a7860bbc0032695b614":[1,0,4,466,1],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#ac3424dce20a5441ec1c434378dca1307":[1,0,4,466,7],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#acce7213815dfddebad6f7b78a7924917":[1,0,4,466,2],
-"interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#ae46bc469c9355e902e0a50b3e339292e":[1,0,4,466,3],
 "interface_qt_gui_1_1_i_q_plain_text_edit_signals.html#af7a43ec818a0b8792f42dd7df7937521":[1,0,4,466,6],
 "interface_qt_gui_1_1_i_q_print_dialog_signals.html":[1,0,4,467],
 "interface_qt_gui_1_1_i_q_print_dialog_signals.html#afebd78f2d41671a15879dff1ee7e1395":[1,0,4,467,0],
@@ -215,39 +249,5 @@ var NAVTREEINDEX109 =
 "interface_qt_gui_1_1_i_q_session_manager_signals.html":[1,0,4,480],
 "interface_qt_gui_1_1_i_q_shortcut_signals.html":[1,0,4,481],
 "interface_qt_gui_1_1_i_q_shortcut_signals.html#a0163b523453648588607fd0723b8bc6c":[1,0,4,481,1],
-"interface_qt_gui_1_1_i_q_shortcut_signals.html#a9fd0cca02ecef1d9325b19966de0b1eb":[1,0,4,481,0],
-"interface_qt_gui_1_1_i_q_size_grip_signals.html":[1,0,4,482],
-"interface_qt_gui_1_1_i_q_slider_signals.html":[1,0,4,483],
-"interface_qt_gui_1_1_i_q_sort_filter_proxy_model_signals.html":[1,0,4,484],
-"interface_qt_gui_1_1_i_q_sound_signals.html":[1,0,4,485],
-"interface_qt_gui_1_1_i_q_spin_box_signals.html":[1,0,4,486],
-"interface_qt_gui_1_1_i_q_spin_box_signals.html#acc94662dcd65ad78fa99e1ea3efa2199":[1,0,4,486,1],
-"interface_qt_gui_1_1_i_q_spin_box_signals.html#accbfd9e587a64b16d5f12671cfc59d56":[1,0,4,486,0],
-"interface_qt_gui_1_1_i_q_splash_screen_signals.html":[1,0,4,487],
-"interface_qt_gui_1_1_i_q_splash_screen_signals.html#a088ca8f77e28b2c180ef7f10313ab767":[1,0,4,487,0],
-"interface_qt_gui_1_1_i_q_splitter_handle_signals.html":[1,0,4,489],
-"interface_qt_gui_1_1_i_q_splitter_signals.html":[1,0,4,488],
-"interface_qt_gui_1_1_i_q_splitter_signals.html#a74c9cac1e19c8ec55f6c268581ac00a5":[1,0,4,488,0],
-"interface_qt_gui_1_1_i_q_stacked_layout_signals.html":[1,0,4,490],
-"interface_qt_gui_1_1_i_q_stacked_layout_signals.html#a0d22e190a72a61a37fc83e778a3cc530":[1,0,4,490,0],
-"interface_qt_gui_1_1_i_q_stacked_layout_signals.html#aa5b3eaf40096fcd5277454a912c904b2":[1,0,4,490,1],
-"interface_qt_gui_1_1_i_q_stacked_widget_signals.html":[1,0,4,491],
-"interface_qt_gui_1_1_i_q_stacked_widget_signals.html#ac7fcd0b5b58e957522bce8364e51c542":[1,0,4,491,1],
-"interface_qt_gui_1_1_i_q_stacked_widget_signals.html#add68e8f65dd017a0aac43a1beb38b6e2":[1,0,4,491,0],
-"interface_qt_gui_1_1_i_q_standard_item_model_signals.html":[1,0,4,492],
-"interface_qt_gui_1_1_i_q_standard_item_model_signals.html#a1caf0bdf05229c9b46d7d3ff0a40a9e8":[1,0,4,492,0],
-"interface_qt_gui_1_1_i_q_status_bar_signals.html":[1,0,4,493],
-"interface_qt_gui_1_1_i_q_status_bar_signals.html#a141244bd2368213ae4633fcffc411a7a":[1,0,4,493,0],
-"interface_qt_gui_1_1_i_q_string_list_model_signals.html":[1,0,4,494],
-"interface_qt_gui_1_1_i_q_style_factory_interface.html":[1,0,4,370],
-"interface_qt_gui_1_1_i_q_style_factory_interface.html#ab6a8728f58440d6a52c37f13b07a5605":[1,0,4,370,0],
-"interface_qt_gui_1_1_i_q_style_plugin_signals.html":[1,0,4,496],
-"interface_qt_gui_1_1_i_q_style_signals.html":[1,0,4,495],
-"interface_qt_gui_1_1_i_q_styled_item_delegate_signals.html":[1,0,4,497],
-"interface_qt_gui_1_1_i_q_swipe_gesture_signals.html":[1,0,4,498],
-"interface_qt_gui_1_1_i_q_syntax_highlighter_signals.html":[1,0,4,499],
-"interface_qt_gui_1_1_i_q_system_tray_icon_signals.html":[1,0,4,500],
-"interface_qt_gui_1_1_i_q_system_tray_icon_signals.html#a21c5e34105d828dd2e6bb3bfd97cf7c3":[1,0,4,500,1],
-"interface_qt_gui_1_1_i_q_system_tray_icon_signals.html#ae148da0334a67372c8453df658949a7b":[1,0,4,500,0],
-"interface_qt_gui_1_1_i_q_tab_bar_signals.html":[1,0,4,501]
+"interface_qt_gui_1_1_i_q_shortcut_signals.html#a9fd0cca02ecef1d9325b19966de0b1eb":[1,0,4,481,0]
 };
