@@ -1,7 +1,5 @@
 var NAVTREEINDEX31 =
 {
-"class_qt_gui_1_1_q_action_group.html#a74f87a3562837004c16b0ab051959245":[1,0,4,14,17],
-"class_qt_gui_1_1_q_action_group.html#a774bcf08b8600943defc042ec71ab57b":[1,0,4,14,24],
 "class_qt_gui_1_1_q_action_group.html#a7abbde2479142fd0a33824d1dece2a35":[1,0,4,14,8],
 "class_qt_gui_1_1_q_action_group.html#aa284c3a276cc6080b4b4a2dab832689f":[1,0,4,14,20],
 "class_qt_gui_1_1_q_action_group.html#aa664fcd4eb888b6db1139e43cebb7af9":[1,0,4,14,22],
@@ -20,77 +18,77 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_application.html":[1,0,4,15],
 "class_qt_gui_1_1_q_application.html#a1020d7cf92ea554ac4ae3424f6baeccb":[1,0,4,15,62],
 "class_qt_gui_1_1_q_application.html#a17a797f7b215cefee126c49bd135b6c5":[1,0,4,15,58],
-"class_qt_gui_1_1_q_application.html#a1cf498b6becbea53a05f89e59ee55a0d":[1,0,4,15,49],
-"class_qt_gui_1_1_q_application.html#a23a87905ddb6a5e17437977c4066d8b7":[1,0,4,15,18],
-"class_qt_gui_1_1_q_application.html#a25ab87e26c92780c18b4256b590f865b":[1,0,4,15,12],
-"class_qt_gui_1_1_q_application.html#a283ce3f1e8effb7c1e7cac06f4036acd":[1,0,4,15,45],
+"class_qt_gui_1_1_q_application.html#a1cf498b6becbea53a05f89e59ee55a0d":[1,0,4,15,50],
+"class_qt_gui_1_1_q_application.html#a23a87905ddb6a5e17437977c4066d8b7":[1,0,4,15,19],
+"class_qt_gui_1_1_q_application.html#a25ab87e26c92780c18b4256b590f865b":[1,0,4,15,13],
+"class_qt_gui_1_1_q_application.html#a283ce3f1e8effb7c1e7cac06f4036acd":[1,0,4,15,46],
 "class_qt_gui_1_1_q_application.html#a2b0dec912c5c927a2606c52a5cd5d3b6":[1,0,4,15,8],
-"class_qt_gui_1_1_q_application.html#a2b2db1c414d23dc5804edf18cde22a78":[1,0,4,15,16],
-"class_qt_gui_1_1_q_application.html#a386c2378f1ee8e5c7baa712f7b43c4b4":[1,0,4,15,42],
+"class_qt_gui_1_1_q_application.html#a2b2db1c414d23dc5804edf18cde22a78":[1,0,4,15,17],
+"class_qt_gui_1_1_q_application.html#a386c2378f1ee8e5c7baa712f7b43c4b4":[1,0,4,15,43],
 "class_qt_gui_1_1_q_application.html#a3ce2637f444f8e102aa871dd8083121a":[1,0,4,15,64],
-"class_qt_gui_1_1_q_application.html#a443d3aab83d5059825618b3adb60a31a":[1,0,4,15,51],
-"class_qt_gui_1_1_q_application.html#a46baa0366f9b7b6e47d4e20a744bc5a6":[1,0,4,15,20],
-"class_qt_gui_1_1_q_application.html#a480d995a17dcab45e16b3238443d01ad":[1,0,4,15,53],
+"class_qt_gui_1_1_q_application.html#a443d3aab83d5059825618b3adb60a31a":[1,0,4,15,52],
+"class_qt_gui_1_1_q_application.html#a46baa0366f9b7b6e47d4e20a744bc5a6":[1,0,4,15,21],
+"class_qt_gui_1_1_q_application.html#a480d995a17dcab45e16b3238443d01ad":[1,0,4,15,54],
 "class_qt_gui_1_1_q_application.html#a4bd3a72cdeaf32eaa4d79d5664025c67":[1,0,4,15,76],
-"class_qt_gui_1_1_q_application.html#a4ffb73e14cb19582e7dea19bf7752322":[1,0,4,15,52],
-"class_qt_gui_1_1_q_application.html#a584c97572067e346da90f6723d6edaee":[1,0,4,15,55],
-"class_qt_gui_1_1_q_application.html#a59aeb40a7c3333913d36511eacabc8d8":[1,0,4,15,41],
-"class_qt_gui_1_1_q_application.html#a5ca47e6811408f5588cdf23318073239":[1,0,4,15,19],
-"class_qt_gui_1_1_q_application.html#a5dc1409c9c0801690dea1878c3b9711d":[1,0,4,15,23],
-"class_qt_gui_1_1_q_application.html#a5e48c1f4ccebafd491379997b78db22e":[1,0,4,15,40],
+"class_qt_gui_1_1_q_application.html#a4ffb73e14cb19582e7dea19bf7752322":[1,0,4,15,53],
+"class_qt_gui_1_1_q_application.html#a584c97572067e346da90f6723d6edaee":[1,0,4,15,56],
+"class_qt_gui_1_1_q_application.html#a59aeb40a7c3333913d36511eacabc8d8":[1,0,4,15,42],
+"class_qt_gui_1_1_q_application.html#a59f59928cb5058447ea40890f3dc1fcd":[1,0,4,15,11],
+"class_qt_gui_1_1_q_application.html#a5ca47e6811408f5588cdf23318073239":[1,0,4,15,20],
+"class_qt_gui_1_1_q_application.html#a5dc1409c9c0801690dea1878c3b9711d":[1,0,4,15,24],
+"class_qt_gui_1_1_q_application.html#a5e48c1f4ccebafd491379997b78db22e":[1,0,4,15,41],
 "class_qt_gui_1_1_q_application.html#a6016215f099e4d443c6904c0cc1a57f5":[1,0,4,15,71],
-"class_qt_gui_1_1_q_application.html#a6d07738083676255127d7f5f09eb98bc":[1,0,4,15,34],
+"class_qt_gui_1_1_q_application.html#a6d07738083676255127d7f5f09eb98bc":[1,0,4,15,35],
 "class_qt_gui_1_1_q_application.html#a6e0908faa9ba0bf6341aa7f3b62fdb3e":[1,0,4,15,61],
-"class_qt_gui_1_1_q_application.html#a6f6703e12e70a74f3d57bcab1ab978a5":[1,0,4,15,22],
+"class_qt_gui_1_1_q_application.html#a6f6703e12e70a74f3d57bcab1ab978a5":[1,0,4,15,23],
 "class_qt_gui_1_1_q_application.html#a70c8b88af9f424e4327341347a7d38d8":[1,0,4,15,73],
 "class_qt_gui_1_1_q_application.html#a740488a79eee34f9397eea5348c16c78":[1,0,4,15,66],
-"class_qt_gui_1_1_q_application.html#a75dddcbe45f2a338bac660d388dfb0dd":[1,0,4,15,17],
-"class_qt_gui_1_1_q_application.html#a77037e678dbb1f3752298b0f865b52fc":[1,0,4,15,50],
-"class_qt_gui_1_1_q_application.html#a798e48fa7b2d524e0f8f86e3d18343c1":[1,0,4,15,38],
-"class_qt_gui_1_1_q_application.html#a7e35ec3fbb057996e89108b0792df61f":[1,0,4,15,36],
-"class_qt_gui_1_1_q_application.html#a7f32691bbe935bc6d8f9a3097164b8bb":[1,0,4,15,33],
-"class_qt_gui_1_1_q_application.html#a8377efb31b0cdcc05a4acb29a65c39b8":[1,0,4,15,24],
-"class_qt_gui_1_1_q_application.html#a853b9d87a25a6bf6746456582c014ae1":[1,0,4,15,48],
+"class_qt_gui_1_1_q_application.html#a75dddcbe45f2a338bac660d388dfb0dd":[1,0,4,15,18],
+"class_qt_gui_1_1_q_application.html#a77037e678dbb1f3752298b0f865b52fc":[1,0,4,15,51],
+"class_qt_gui_1_1_q_application.html#a798e48fa7b2d524e0f8f86e3d18343c1":[1,0,4,15,39],
+"class_qt_gui_1_1_q_application.html#a7e35ec3fbb057996e89108b0792df61f":[1,0,4,15,37],
+"class_qt_gui_1_1_q_application.html#a7f32691bbe935bc6d8f9a3097164b8bb":[1,0,4,15,34],
+"class_qt_gui_1_1_q_application.html#a8377efb31b0cdcc05a4acb29a65c39b8":[1,0,4,15,25],
+"class_qt_gui_1_1_q_application.html#a853b9d87a25a6bf6746456582c014ae1":[1,0,4,15,49],
 "class_qt_gui_1_1_q_application.html#a8963d1bf1b9ee2ae9773f4c1d85b07f9":[1,0,4,15,9],
 "class_qt_gui_1_1_q_application.html#a897038cc6aab12a1ecde1fab1745942d":[1,0,4,15,69],
 "class_qt_gui_1_1_q_application.html#a8accd846579c3aecbcf736ce663e71ff":[1,0,4,15,74],
 "class_qt_gui_1_1_q_application.html#a8b43e9bda60bfe93b1bd556bd1548fb4":[1,0,4,15,1],
-"class_qt_gui_1_1_q_application.html#a8b43e9bda60bfe93b1bd556bd1548fb4":[1,0,4,15,1,0],
-"class_qt_gui_1_1_q_application.html#a8b43e9bda60bfe93b1bd556bd1548fb4":[1,0,4,15,1,1],
-"class_qt_gui_1_1_q_application.html#a8b43e9bda60bfe93b1bd556bd1548fb4":[1,0,4,15,1,2],
-"class_qt_gui_1_1_q_application.html#a8c1a89597ef7cb02ab22063399880c10":[1,0,4,15,14],
-"class_qt_gui_1_1_q_application.html#a8d556a357693de743b971a572d610530":[1,0,4,15,56],
-"class_qt_gui_1_1_q_application.html#a8de69572f84d7d1a0d5f4d4f7a63b053":[1,0,4,15,21],
-"class_qt_gui_1_1_q_application.html#a90da0634b07ce01934b702cfaf0d30b3":[1,0,4,15,13],
+"class_qt_gui_1_1_q_application.html#a8b43e9bda60bfe93b1bd556bd1548fb4a16486f0656a5652ec1b987f3fc91aa7c":[1,0,4,15,1,2],
+"class_qt_gui_1_1_q_application.html#a8b43e9bda60bfe93b1bd556bd1548fb4a6d812511cccea3df5b822b8de5e3a378":[1,0,4,15,1,0],
+"class_qt_gui_1_1_q_application.html#a8b43e9bda60bfe93b1bd556bd1548fb4a7b7d9cd7e3dfd0ec711979d401fe9bc2":[1,0,4,15,1,1],
+"class_qt_gui_1_1_q_application.html#a8c1a89597ef7cb02ab22063399880c10":[1,0,4,15,15],
+"class_qt_gui_1_1_q_application.html#a8d556a357693de743b971a572d610530":[1,0,4,15,57],
+"class_qt_gui_1_1_q_application.html#a8de69572f84d7d1a0d5f4d4f7a63b053":[1,0,4,15,22],
+"class_qt_gui_1_1_q_application.html#a90da0634b07ce01934b702cfaf0d30b3":[1,0,4,15,14],
 "class_qt_gui_1_1_q_application.html#a9179905d1baf4bcb33d8c113a2674e3c":[1,0,4,15,3],
-"class_qt_gui_1_1_q_application.html#a938e1e2b35d4567bce62d795be0e5eb0":[1,0,4,15,27],
-"class_qt_gui_1_1_q_application.html#a943593542a0e027ba6e65824dfe0506b":[1,0,4,15,31],
+"class_qt_gui_1_1_q_application.html#a938e1e2b35d4567bce62d795be0e5eb0":[1,0,4,15,28],
+"class_qt_gui_1_1_q_application.html#a943593542a0e027ba6e65824dfe0506b":[1,0,4,15,32],
 "class_qt_gui_1_1_q_application.html#a9f62ff2f12c056a12fdc346283a50e97":[1,0,4,15,84],
 "class_qt_gui_1_1_q_application.html#aa060676811ad8904716f27b44984e29b":[1,0,4,15,0],
-"class_qt_gui_1_1_q_application.html#aa060676811ad8904716f27b44984e29b":[1,0,4,15,0,0],
-"class_qt_gui_1_1_q_application.html#aa060676811ad8904716f27b44984e29b":[1,0,4,15,0,1],
-"class_qt_gui_1_1_q_application.html#aa060676811ad8904716f27b44984e29b":[1,0,4,15,0,2],
-"class_qt_gui_1_1_q_application.html#aa125c7f6da6d7d6d8812fbaa984fe17c":[1,0,4,15,37],
-"class_qt_gui_1_1_q_application.html#aa3be89e7c249b601dccdadac2c6ca3f8":[1,0,4,15,28],
+"class_qt_gui_1_1_q_application.html#aa060676811ad8904716f27b44984e29ba0f8a7090748b916343d12bc92784dece":[1,0,4,15,0,0],
+"class_qt_gui_1_1_q_application.html#aa060676811ad8904716f27b44984e29ba71c3a2cffe364d210f4cc633d2f03989":[1,0,4,15,0,1],
+"class_qt_gui_1_1_q_application.html#aa060676811ad8904716f27b44984e29babb3bb0726f6e6d47754cb5b681ab069c":[1,0,4,15,0,2],
+"class_qt_gui_1_1_q_application.html#aa125c7f6da6d7d6d8812fbaa984fe17c":[1,0,4,15,38],
+"class_qt_gui_1_1_q_application.html#aa3be89e7c249b601dccdadac2c6ca3f8":[1,0,4,15,29],
 "class_qt_gui_1_1_q_application.html#ab1eca8e89fa1748657c3f35d1704a56a":[1,0,4,15,78],
-"class_qt_gui_1_1_q_application.html#ab638775d484d9569b5f1d081dcbd143a":[1,0,4,15,43],
+"class_qt_gui_1_1_q_application.html#ab638775d484d9569b5f1d081dcbd143a":[1,0,4,15,44],
 "class_qt_gui_1_1_q_application.html#ab826b405e7ce14c41ff6f975c4f7e9f1":[1,0,4,15,68],
 "class_qt_gui_1_1_q_application.html#abc96e70e72be4858182d748e66e65c82":[1,0,4,15,81],
-"class_qt_gui_1_1_q_application.html#abe6005986270f1f65e8887d13c4fcb6e":[1,0,4,15,35],
-"class_qt_gui_1_1_q_application.html#ac35c8c3da9fb09f0e84ec6436eb9f58f":[1,0,4,15,57],
+"class_qt_gui_1_1_q_application.html#abe6005986270f1f65e8887d13c4fcb6e":[1,0,4,15,36],
 "class_qt_gui_1_1_q_application.html#ac45e9fb56432b9dd732638dfe2d8a48d":[1,0,4,15,60],
-"class_qt_gui_1_1_q_application.html#ac6975b4d4078e430984e72ae3965a132":[1,0,4,15,26],
+"class_qt_gui_1_1_q_application.html#ac6975b4d4078e430984e72ae3965a132":[1,0,4,15,27],
 "class_qt_gui_1_1_q_application.html#ac77b462049d2a88eda9e492ac5fdecf0":[1,0,4,15,80],
 "class_qt_gui_1_1_q_application.html#ac7dbe7b06046f2bc7c7fc9e117d3d049":[1,0,4,15,7],
-"class_qt_gui_1_1_q_application.html#ac7ff7af58d45aa107f5d333bcca91587":[1,0,4,15,25],
+"class_qt_gui_1_1_q_application.html#ac7ff7af58d45aa107f5d333bcca91587":[1,0,4,15,26],
 "class_qt_gui_1_1_q_application.html#ac8cdcf3f28cd43a64b09e80ba6cf5347":[1,0,4,15,6],
 "class_qt_gui_1_1_q_application.html#acacfc509c81d9a86cab07742e9eb7b60":[1,0,4,15,75],
-"class_qt_gui_1_1_q_application.html#acc3324e5fbe9b5b29685c2a09da9ed71":[1,0,4,15,32],
+"class_qt_gui_1_1_q_application.html#acc3324e5fbe9b5b29685c2a09da9ed71":[1,0,4,15,33],
 "class_qt_gui_1_1_q_application.html#acd5c6efc8958bf37a3b8c30612e2376d":[1,0,4,15,79],
-"class_qt_gui_1_1_q_application.html#ad1c663b136d300798bd790fc8ade03f5":[1,0,4,15,44],
+"class_qt_gui_1_1_q_application.html#ad1c663b136d300798bd790fc8ade03f5":[1,0,4,15,45],
 "class_qt_gui_1_1_q_application.html#ad23e66d75f6dc456d2158d77ca82ab87":[1,0,4,15,65],
-"class_qt_gui_1_1_q_application.html#ad27ca284189cd7cc148d3f498a934f84":[1,0,4,15,39],
-"class_qt_gui_1_1_q_application.html#ad36b504e3904de2ebc43991294d110f8":[1,0,4,15,46],
+"class_qt_gui_1_1_q_application.html#ad27ca284189cd7cc148d3f498a934f84":[1,0,4,15,40],
+"class_qt_gui_1_1_q_application.html#ad36b504e3904de2ebc43991294d110f8":[1,0,4,15,47],
 "class_qt_gui_1_1_q_application.html#ad77a79a4f7797de2ce67d240d5a694aa":[1,0,4,15,4],
 "class_qt_gui_1_1_q_application.html#ad9c44c241c6b24129631ac8a0cfb1aa7":[1,0,4,15,77],
 "class_qt_gui_1_1_q_application.html#adf8d123926319d01197b43b2bcf8b1c3":[1,0,4,15,5],
@@ -98,19 +96,19 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_application.html#ae8d46cc2e209d8c34c29b68717421ad6":[1,0,4,15,70],
 "class_qt_gui_1_1_q_application.html#ae90e24f7d8dd2a0c59733e3b7d6c0982":[1,0,4,15,67],
 "class_qt_gui_1_1_q_application.html#aeb55af428bea03fb2949bc5964a21152":[1,0,4,15,10],
-"class_qt_gui_1_1_q_application.html#aeb889e942f13113625a4c5990e5a83ce":[1,0,4,15,15],
+"class_qt_gui_1_1_q_application.html#aeb889e942f13113625a4c5990e5a83ce":[1,0,4,15,16],
 "class_qt_gui_1_1_q_application.html#aed046652a3e595bc3779e452845172f5":[1,0,4,15,72],
 "class_qt_gui_1_1_q_application.html#aeec70a8360a03e5ae0a4a8cd5b6a88eb":[1,0,4,15,59],
 "class_qt_gui_1_1_q_application.html#af0b23720c89b6eea66ce1854656845f2":[1,0,4,15,82],
-"class_qt_gui_1_1_q_application.html#af0c6407c11853e8322c4fb32e8beea08":[1,0,4,15,54],
-"class_qt_gui_1_1_q_application.html#af0f119b5ec511a6e23d72d983ea6204e":[1,0,4,15,30],
+"class_qt_gui_1_1_q_application.html#af0c6407c11853e8322c4fb32e8beea08":[1,0,4,15,55],
+"class_qt_gui_1_1_q_application.html#af0f119b5ec511a6e23d72d983ea6204e":[1,0,4,15,31],
 "class_qt_gui_1_1_q_application.html#af271abd8a2acd67eca40be46f24584ec":[1,0,4,15,63],
-"class_qt_gui_1_1_q_application.html#af5916db5afa273ff410b260d668bca05":[1,0,4,15,11],
+"class_qt_gui_1_1_q_application.html#af5916db5afa273ff410b260d668bca05":[1,0,4,15,12],
 "class_qt_gui_1_1_q_application.html#af7d4d3fcf51711236d7261fdcee91fe9":[1,0,4,15,2],
 "class_qt_gui_1_1_q_application.html#afc2f0fc9acfaa7d49868ebece3c2e442":[1,0,4,15,85],
-"class_qt_gui_1_1_q_application.html#afd42e7fb1c2f6fb3c83144ac85aac628":[1,0,4,15,29],
+"class_qt_gui_1_1_q_application.html#afd42e7fb1c2f6fb3c83144ac85aac628":[1,0,4,15,30],
 "class_qt_gui_1_1_q_application.html#afe715912f6d97267bc686e8870ae3173":[1,0,4,15,83],
-"class_qt_gui_1_1_q_application.html#afe721aa2a6bdd4e419d877f39cc41727":[1,0,4,15,47],
+"class_qt_gui_1_1_q_application.html#afe721aa2a6bdd4e419d877f39cc41727":[1,0,4,15,48],
 "class_qt_gui_1_1_q_bitmap.html":[1,0,4,16],
 "class_qt_gui_1_1_q_bitmap.html#a39ea2f16fbf8f60b116bab6ded018603":[1,0,4,16,3],
 "class_qt_gui_1_1_q_bitmap.html#a6a06d851b47a4d09d446c832e601fd8b":[1,0,4,16,8],
@@ -157,12 +155,12 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_box_layout.html#a8fb363dacc7f44b1fcfd5f7026d5ca73":[1,0,4,17,23],
 "class_qt_gui_1_1_q_box_layout.html#a9a9d14e04c1e1a1a1aedd5df36546099":[1,0,4,17,41],
 "class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7":[1,0,4,17,0],
-"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7":[1,0,4,17,0,0],
-"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7":[1,0,4,17,0,1],
-"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7":[1,0,4,17,0,2],
-"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7":[1,0,4,17,0,3],
-"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7":[1,0,4,17,0,4],
-"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7":[1,0,4,17,0,5],
+"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7a08a38277b0309070706f6652eeae9a53":[1,0,4,17,0,1],
+"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7a258f49887ef8d14ac268c92b02503aaa":[1,0,4,17,0,5],
+"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7a63dc349be51108dcfd197c7ab02b486a":[1,0,4,17,0,0],
+"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7ab7b0ea3028791689ea070674776855e2":[1,0,4,17,0,3],
+"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7ad1e80c506f4c89e3c4fb1c1b4867a03c":[1,0,4,17,0,2],
+"class_qt_gui_1_1_q_box_layout.html#a9d3b3e7deb08881e6cdccef48f157dd7af2b1a19a8d0f523d042f9ede79a80804":[1,0,4,17,0,4],
 "class_qt_gui_1_1_q_box_layout.html#aa0c07480028787a15f524d70056ce47c":[1,0,4,17,21],
 "class_qt_gui_1_1_q_box_layout.html#aacc039765e3f5a2bc5aa0b539be64c36":[1,0,4,17,17],
 "class_qt_gui_1_1_q_box_layout.html#aaf1398d2c207a1e7b6c1f572091f8ab1":[1,0,4,17,18],
@@ -207,6 +205,7 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_brush.html#afbc4d84804856930aaad08668d23b8ba":[1,0,4,18,9],
 "class_qt_gui_1_1_q_brush.html#afc6c27f1f8a02b6c9dd5eec097409392":[1,0,4,18,6],
 "class_qt_gui_1_1_q_button_group.html":[1,0,4,19],
+"class_qt_gui_1_1_q_button_group.html#a1473042a86d9a65bac33be42289e97d1":[1,0,4,19,21],
 "class_qt_gui_1_1_q_button_group.html#a1b172bd157a725c009780f9179b6cc63":[1,0,4,19,8],
 "class_qt_gui_1_1_q_button_group.html#a1d2727bd3067d6f66ad1b0b9bd11ac3c":[1,0,4,19,18],
 "class_qt_gui_1_1_q_button_group.html#a217713b92a7b5dbde1feb867043b0389":[1,0,4,19,28],
@@ -214,13 +213,10 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_button_group.html#a34ce70733ceba6b877b0e472af3c750e":[1,0,4,19,3],
 "class_qt_gui_1_1_q_button_group.html#a425c9d5e15c6c166b49af47b8ac4f5bf":[1,0,4,19,22],
 "class_qt_gui_1_1_q_button_group.html#a482037009a125b80a903be78001f3aa9":[1,0,4,19,27],
-"class_qt_gui_1_1_q_button_group.html#a4eec0dec7a5f0d640decc4dbcf90a9e4":[1,0,4,19,25],
 "class_qt_gui_1_1_q_button_group.html#a51cc3c0222aa8effd0c39adab2d42c80":[1,0,4,19,7],
-"class_qt_gui_1_1_q_button_group.html#a53dd90922128954d19cf4656da5c565b":[1,0,4,19,21],
 "class_qt_gui_1_1_q_button_group.html#a58f3f948fe9d47c29407fba10fa0f405":[1,0,4,19,24],
 "class_qt_gui_1_1_q_button_group.html#a5a956fed2355485340ba41b549fef06f":[1,0,4,19,30],
 "class_qt_gui_1_1_q_button_group.html#a5c237d6473127b12d10e87a8e7b25aab":[1,0,4,19,19],
-"class_qt_gui_1_1_q_button_group.html#a5e23344d063f6abb7eb69908ae1ae983":[1,0,4,19,23],
 "class_qt_gui_1_1_q_button_group.html#a61c02d65d186cdbe5d8ca952bf2ba260":[1,0,4,19,13],
 "class_qt_gui_1_1_q_button_group.html#a632a59ab31ce97c4bc901037fc43c854":[1,0,4,19,0],
 "class_qt_gui_1_1_q_button_group.html#a679af6d180016ff461cc725fab0f95bb":[1,0,4,19,14],
@@ -229,6 +225,7 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_button_group.html#a8db9a3e3fb8eff47fd4cee6980b8cfa1":[1,0,4,19,9],
 "class_qt_gui_1_1_q_button_group.html#a915599915a8ede42342845b96c3f65fd":[1,0,4,19,31],
 "class_qt_gui_1_1_q_button_group.html#aa1f22df497ad732c8798e7518092f812":[1,0,4,19,11],
+"class_qt_gui_1_1_q_button_group.html#aa49bdb19bf70f23583dfac1ee6a58007":[1,0,4,19,25],
 "class_qt_gui_1_1_q_button_group.html#aa5a10a84a34804e367afded4bc3cee24":[1,0,4,19,15],
 "class_qt_gui_1_1_q_button_group.html#ab1126b74521d5c8363f8bebe2e3653b9":[1,0,4,19,6],
 "class_qt_gui_1_1_q_button_group.html#abdf9f4c3522cda4adcc0f86bb5357f21":[1,0,4,19,10],
@@ -239,6 +236,7 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_button_group.html#adcd7a3a282794b85aba0ca772d3e3106":[1,0,4,19,16],
 "class_qt_gui_1_1_q_button_group.html#aeb76f00694b76af8b1b721ec97697b91":[1,0,4,19,1],
 "class_qt_gui_1_1_q_button_group.html#af0ed192f0e2794a300ba296833cc7eba":[1,0,4,19,4],
+"class_qt_gui_1_1_q_button_group.html#aff961ba6f31d4ef3cf45c24338ea110d":[1,0,4,19,23],
 "class_qt_gui_1_1_q_calendar_widget.html":[1,0,4,20],
 "class_qt_gui_1_1_q_calendar_widget.html#a01dd48c8001be856713a72203502df08":[1,0,4,20,52],
 "class_qt_gui_1_1_q_calendar_widget.html#a090d90727dd055c06da8c81e9e362b20":[1,0,4,20,42],
@@ -249,5 +247,7 @@ var NAVTREEINDEX31 =
 "class_qt_gui_1_1_q_calendar_widget.html#a1d2088c197c6866dd07a423ebe3ed57e":[1,0,4,20,9],
 "class_qt_gui_1_1_q_calendar_widget.html#a1f2704dcfb1f9e3438690b73284e4710":[1,0,4,20,24],
 "class_qt_gui_1_1_q_calendar_widget.html#a23816c2e019c9bb2b2cda54b1d7016db":[1,0,4,20,31],
-"class_qt_gui_1_1_q_calendar_widget.html#a29d6112ec7d88acdd9608ded8e896974":[1,0,4,20,18]
+"class_qt_gui_1_1_q_calendar_widget.html#a29d6112ec7d88acdd9608ded8e896974":[1,0,4,20,18],
+"class_qt_gui_1_1_q_calendar_widget.html#a2a8f27f50e4f26de1e401899c03ee3ea":[1,0,4,20,37],
+"class_qt_gui_1_1_q_calendar_widget.html#a2eef3b1011798cf851c3e2ed6b3cb5f8":[1,0,4,20,46]
 };
