@@ -1,7 +1,5 @@
 var NAVTREEINDEX36 =
 {
-"class_qt_gui_1_1_q_dock_widget.html#ac0e4f9776db15441e4d93b500596c7c5":[1,0,4,45,10],
-"class_qt_gui_1_1_q_dock_widget.html#ac792ddf87729fb065ec15e9a571ccdef":[1,0,4,45,30],
 "class_qt_gui_1_1_q_dock_widget.html#ac8f8524e288f1da34457b638a2dd22c7":[1,0,4,45,4],
 "class_qt_gui_1_1_q_dock_widget.html#ad7d272472f3d846ce4159454c258e0d5":[1,0,4,45,11],
 "class_qt_gui_1_1_q_dock_widget.html#ad8edae13298e889ed7640af6925e2a4e":[1,0,4,45,2],
@@ -12,7 +10,6 @@ var NAVTREEINDEX36 =
 "class_qt_gui_1_1_q_dock_widget.html#aed88d382d83a641a09d926d77c4a7b6a":[1,0,4,45,32],
 "class_qt_gui_1_1_q_dock_widget.html#aee127bf22e6accfc3651bcb5ea0473a2":[1,0,4,45,5],
 "class_qt_gui_1_1_q_double_spin_box.html":[1,0,4,46],
-"class_qt_gui_1_1_q_double_spin_box.html#a00034a59a71e24b6feae03765fbac87b":[1,0,4,46,26],
 "class_qt_gui_1_1_q_double_spin_box.html#a0e355e3c5904cb241b8938ed78e1ff33":[1,0,4,46,24],
 "class_qt_gui_1_1_q_double_spin_box.html#a108f1783c4c678051fd6fe5d60a5e4f4":[1,0,4,46,15],
 "class_qt_gui_1_1_q_double_spin_box.html#a19a8a49c5ac9124f73bdcb2580d3307e":[1,0,4,46,3],
@@ -35,6 +32,7 @@ var NAVTREEINDEX36 =
 "class_qt_gui_1_1_q_double_spin_box.html#ac81941ea28bb56c8912bc9f4e2f6e7b4":[1,0,4,46,13],
 "class_qt_gui_1_1_q_double_spin_box.html#acea82da1c63416e4233772453008c3a1":[1,0,4,46,8],
 "class_qt_gui_1_1_q_double_spin_box.html#ad3e0cbf554a0c352e86ef6c95cec86fd":[1,0,4,46,14],
+"class_qt_gui_1_1_q_double_spin_box.html#adfee1b0ed27d57156a9256f37de9d2ee":[1,0,4,46,26],
 "class_qt_gui_1_1_q_double_spin_box.html#ae57fa0df8bdac9fd9249c7fe93103d45":[1,0,4,46,10],
 "class_qt_gui_1_1_q_double_spin_box.html#af8d737e1f5b5d25a92f309975121b813":[1,0,4,46,25],
 "class_qt_gui_1_1_q_double_spin_box.html#afa6117004ea500163175d45225a5a52c":[1,0,4,46,21],
@@ -54,8 +52,8 @@ var NAVTREEINDEX36 =
 "class_qt_gui_1_1_q_double_validator.html#a9918e424a0d3c1f3a833230c8bd38e74":[1,0,4,47,12],
 "class_qt_gui_1_1_q_double_validator.html#aa57f0a39ffbac83be37ba45e1f2f88d8":[1,0,4,47,16],
 "class_qt_gui_1_1_q_double_validator.html#ac656a0d46a3d5f2535cc89f2cac5d3c8":[1,0,4,47,0],
-"class_qt_gui_1_1_q_double_validator.html#ac656a0d46a3d5f2535cc89f2cac5d3c8":[1,0,4,47,0,0],
-"class_qt_gui_1_1_q_double_validator.html#ac656a0d46a3d5f2535cc89f2cac5d3c8":[1,0,4,47,0,1],
+"class_qt_gui_1_1_q_double_validator.html#ac656a0d46a3d5f2535cc89f2cac5d3c8a169121637109db9146569d2150bad6af":[1,0,4,47,0,1],
+"class_qt_gui_1_1_q_double_validator.html#ac656a0d46a3d5f2535cc89f2cac5d3c8ac4acefbfd8e15667470cfc37577bdba1":[1,0,4,47,0,0],
 "class_qt_gui_1_1_q_double_validator.html#ad17b5e420797bdd7cb09a37f7d266d1b":[1,0,4,47,10],
 "class_qt_gui_1_1_q_double_validator.html#ae14fde11c8ee0ead8707655f412fe0dd":[1,0,4,47,2],
 "class_qt_gui_1_1_q_double_validator.html#aeb400d2f47049417e31cebe3fe678644":[1,0,4,47,7],
@@ -159,95 +157,97 @@ var NAVTREEINDEX36 =
 "class_qt_gui_1_1_q_error_message.html#aee1a8c1674f499cdbb630a6993b885d4":[1,0,4,54,1],
 "class_qt_gui_1_1_q_error_message.html#af17e4503ad3b7d56be40804622c01846":[1,0,4,54,3],
 "class_qt_gui_1_1_q_file_dialog.html":[1,0,4,55],
-"class_qt_gui_1_1_q_file_dialog.html#a08f4b49a446c852105d94372f838df6c":[1,0,4,55,54],
+"class_qt_gui_1_1_q_file_dialog.html#a08a0af9738ae1d598241079bd6eec3af":[1,0,4,55,26],
+"class_qt_gui_1_1_q_file_dialog.html#a08f4b49a446c852105d94372f838df6c":[1,0,4,55,55],
 "class_qt_gui_1_1_q_file_dialog.html#a0ae19709324de66d8ab1fe1bd2e1b419":[1,0,4,55,0],
-"class_qt_gui_1_1_q_file_dialog.html#a0ae19709324de66d8ab1fe1bd2e1b419":[1,0,4,55,0,0],
-"class_qt_gui_1_1_q_file_dialog.html#a0ae19709324de66d8ab1fe1bd2e1b419":[1,0,4,55,0,1],
-"class_qt_gui_1_1_q_file_dialog.html#a0d3c65d1749beeaabebe2908474103df":[1,0,4,55,31],
+"class_qt_gui_1_1_q_file_dialog.html#a0ae19709324de66d8ab1fe1bd2e1b419a33e7da92dabe69822081980fb62b0c8f":[1,0,4,55,0,1],
+"class_qt_gui_1_1_q_file_dialog.html#a0ae19709324de66d8ab1fe1bd2e1b419a57fc4c3292212561cba1bfc6161a14fb":[1,0,4,55,0,0],
+"class_qt_gui_1_1_q_file_dialog.html#a0d3c65d1749beeaabebe2908474103df":[1,0,4,55,32],
 "class_qt_gui_1_1_q_file_dialog.html#a116dcf01a7f64639d6af6221e4a7d627":[1,0,4,55,21],
 "class_qt_gui_1_1_q_file_dialog.html#a122a7332a81a6176e7001c229314836a":[1,0,4,55,7],
-"class_qt_gui_1_1_q_file_dialog.html#a14215f4dc05d5dcc0652db94ae91cfb7":[1,0,4,55,40],
+"class_qt_gui_1_1_q_file_dialog.html#a14215f4dc05d5dcc0652db94ae91cfb7":[1,0,4,55,41],
 "class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70c":[1,0,4,55,1],
-"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70c":[1,0,4,55,1,0],
-"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70c":[1,0,4,55,1,1],
-"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70c":[1,0,4,55,1,2],
-"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70c":[1,0,4,55,1,3],
-"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70c":[1,0,4,55,1,4],
-"class_qt_gui_1_1_q_file_dialog.html#a1db03f4b04caafc738f14d225c3dce3f":[1,0,4,55,50],
+"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70ca16daf049bb45717e433b04b2e7d909ac":[1,0,4,55,1,2],
+"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70ca1e621df39e053ff6bc7db7bb1c616cc1":[1,0,4,55,1,1],
+"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70ca4e32a4a517b6d6b5b4dca9936588dcc4":[1,0,4,55,1,3],
+"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70cac4408d335012a56ff58937d78050efad":[1,0,4,55,1,0],
+"class_qt_gui_1_1_q_file_dialog.html#a1a4b6cdcf455047a11100a1cad94d70cad98ac12774fca5c3cbaffe276840c55f":[1,0,4,55,1,4],
+"class_qt_gui_1_1_q_file_dialog.html#a1db03f4b04caafc738f14d225c3dce3f":[1,0,4,55,51],
 "class_qt_gui_1_1_q_file_dialog.html#a2010c403aee9f2008268914dfa19ffbf":[1,0,4,55,17],
-"class_qt_gui_1_1_q_file_dialog.html#a250db64b57e8c3a6f82865b4d80f56e2":[1,0,4,55,56],
-"class_qt_gui_1_1_q_file_dialog.html#a2626ccf3e7e5e9a3947a7cafd85a25ec":[1,0,4,55,60],
+"class_qt_gui_1_1_q_file_dialog.html#a250db64b57e8c3a6f82865b4d80f56e2":[1,0,4,55,57],
+"class_qt_gui_1_1_q_file_dialog.html#a2626ccf3e7e5e9a3947a7cafd85a25ec":[1,0,4,55,61],
 "class_qt_gui_1_1_q_file_dialog.html#a2ceb1c36f9290e3bf08fe539d7fc4493":[1,0,4,55,20],
-"class_qt_gui_1_1_q_file_dialog.html#a2da95e9a4cf6e1096c4a12515644195e":[1,0,4,55,48],
+"class_qt_gui_1_1_q_file_dialog.html#a2da95e9a4cf6e1096c4a12515644195e":[1,0,4,55,49],
 "class_qt_gui_1_1_q_file_dialog.html#a2e46b4962220bdaca02783730e56002f":[1,0,4,55,68],
 "class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3],
-"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3,0],
-"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3,1],
-"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3,2],
-"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3,3],
-"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3,4],
-"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3,5],
-"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893":[1,0,4,55,3,6],
+"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893a131fb182a881796e7606ed6da27f1197":[1,0,4,55,3,5],
+"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893a42c368bb89fe46fe1e95b246eb3aeaff":[1,0,4,55,3,4],
+"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893a725f45638b7b7517f27ac50eecf35173":[1,0,4,55,3,3],
+"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893a768ea077d609ec697cadfcfa39240496":[1,0,4,55,3,0],
+"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893adba4d8a52db0c0380369c3aebfc7602e":[1,0,4,55,3,2],
+"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893ae6aff4ccadd804d64ce402085fca0804":[1,0,4,55,3,6],
+"class_qt_gui_1_1_q_file_dialog.html#a31678644e98bc36fba5a9e3487678893afee9c6664fe41c467f2cab634398f0a3":[1,0,4,55,3,1],
 "class_qt_gui_1_1_q_file_dialog.html#a31766cf065cd5cdbbef12fa431003934":[1,0,4,55,66],
-"class_qt_gui_1_1_q_file_dialog.html#a33d4796811c13de13b2ee1ef28cb8db9":[1,0,4,55,36],
-"class_qt_gui_1_1_q_file_dialog.html#a38c330b2817e6c6ea7832b28ebb16a6a":[1,0,4,55,33],
+"class_qt_gui_1_1_q_file_dialog.html#a33d4796811c13de13b2ee1ef28cb8db9":[1,0,4,55,37],
+"class_qt_gui_1_1_q_file_dialog.html#a38c330b2817e6c6ea7832b28ebb16a6a":[1,0,4,55,34],
 "class_qt_gui_1_1_q_file_dialog.html#a3d09e156a827ae2f23b786aab37c6df0":[1,0,4,55,13],
-"class_qt_gui_1_1_q_file_dialog.html#a44f820f5df1d6c73a1c665310552be0f":[1,0,4,55,46],
+"class_qt_gui_1_1_q_file_dialog.html#a44f820f5df1d6c73a1c665310552be0f":[1,0,4,55,47],
 "class_qt_gui_1_1_q_file_dialog.html#a45879853abf3b017a41a590126163c2c":[1,0,4,55,62],
-"class_qt_gui_1_1_q_file_dialog.html#a45b96c592d65c560dd61acc361d7e45e":[1,0,4,55,61],
-"class_qt_gui_1_1_q_file_dialog.html#a499c37c236de88bc4a44b6f0ae994b66":[1,0,4,55,38],
+"class_qt_gui_1_1_q_file_dialog.html#a499c37c236de88bc4a44b6f0ae994b66":[1,0,4,55,39],
 "class_qt_gui_1_1_q_file_dialog.html#a4b7e1f5c8bd81cf42780d8552c8d398f":[1,0,4,55,67],
 "class_qt_gui_1_1_q_file_dialog.html#a50fc2ab661a214dc0856d660972a54fb":[1,0,4,55,8],
-"class_qt_gui_1_1_q_file_dialog.html#a542c16f21724ce4aaf8fcb866cf1579e":[1,0,4,55,47],
+"class_qt_gui_1_1_q_file_dialog.html#a542c16f21724ce4aaf8fcb866cf1579e":[1,0,4,55,48],
 "class_qt_gui_1_1_q_file_dialog.html#a5455b0120fc1104217ca330ca690f93d":[1,0,4,55,10],
 "class_qt_gui_1_1_q_file_dialog.html#a56cd7d0aaa68dbe660e2399a989434b9":[1,0,4,55,12],
 "class_qt_gui_1_1_q_file_dialog.html#a5e41effbffdca9158044465e36d7446b":[1,0,4,55,14],
 "class_qt_gui_1_1_q_file_dialog.html#a63f60bc3567ba4e9bebe8efabbec82c9":[1,0,4,55,18],
 "class_qt_gui_1_1_q_file_dialog.html#a67e6e5ea192faa6734cecbebe55a54fb":[1,0,4,55,16],
 "class_qt_gui_1_1_q_file_dialog.html#a6c33f24676815ef1533970220feb14a5":[1,0,4,55,65],
-"class_qt_gui_1_1_q_file_dialog.html#a6c9290fec34f2e9b2e663701138e0098":[1,0,4,55,41],
+"class_qt_gui_1_1_q_file_dialog.html#a6c9290fec34f2e9b2e663701138e0098":[1,0,4,55,42],
 "class_qt_gui_1_1_q_file_dialog.html#a73d68fd0346d14d043a8bb5108e7d80a":[1,0,4,55,23],
 "class_qt_gui_1_1_q_file_dialog.html#a75be4a7b802935fe6c3e2b178f788372":[1,0,4,55,6],
-"class_qt_gui_1_1_q_file_dialog.html#a777aaa7127def8af1eb511fde4ec498b":[1,0,4,55,43],
+"class_qt_gui_1_1_q_file_dialog.html#a777aaa7127def8af1eb511fde4ec498b":[1,0,4,55,44],
 "class_qt_gui_1_1_q_file_dialog.html#a78e2c8793cd65bcffeff98f30c9c4926":[1,0,4,55,64],
-"class_qt_gui_1_1_q_file_dialog.html#a7b0b37044570f0862de9854911382cfd":[1,0,4,55,29],
-"class_qt_gui_1_1_q_file_dialog.html#a846fa3e942d95bdf0b6139f148b9b462":[1,0,4,55,34],
-"class_qt_gui_1_1_q_file_dialog.html#a864d43c4e279a632d535b8fe63d1dec8":[1,0,4,55,59],
+"class_qt_gui_1_1_q_file_dialog.html#a7b0b37044570f0862de9854911382cfd":[1,0,4,55,30],
+"class_qt_gui_1_1_q_file_dialog.html#a846fa3e942d95bdf0b6139f148b9b462":[1,0,4,55,35],
+"class_qt_gui_1_1_q_file_dialog.html#a864d43c4e279a632d535b8fe63d1dec8":[1,0,4,55,60],
 "class_qt_gui_1_1_q_file_dialog.html#a8b400c7e8592b03b61b874065c5a8064":[1,0,4,55,5],
-"class_qt_gui_1_1_q_file_dialog.html#a8d03a18761bae5e677700dfff8687d2d":[1,0,4,55,37],
-"class_qt_gui_1_1_q_file_dialog.html#a8f13ab282a79f522ae1130dc1594770c":[1,0,4,55,35],
+"class_qt_gui_1_1_q_file_dialog.html#a8d03a18761bae5e677700dfff8687d2d":[1,0,4,55,38],
+"class_qt_gui_1_1_q_file_dialog.html#a8f13ab282a79f522ae1130dc1594770c":[1,0,4,55,36],
 "class_qt_gui_1_1_q_file_dialog.html#a9407f3e4af88991e0a8552d7b558d4f2":[1,0,4,55,15],
 "class_qt_gui_1_1_q_file_dialog.html#a97b35b542312aa25a1dca764cc22d5d5":[1,0,4,55,4],
-"class_qt_gui_1_1_q_file_dialog.html#a97b35b542312aa25a1dca764cc22d5d5":[1,0,4,55,4,0],
-"class_qt_gui_1_1_q_file_dialog.html#a97b35b542312aa25a1dca764cc22d5d5":[1,0,4,55,4,1],
-"class_qt_gui_1_1_q_file_dialog.html#a9a6be7c5a0b4a13ddc59f9eb52036918":[1,0,4,55,39],
-"class_qt_gui_1_1_q_file_dialog.html#aa67f13bbaf21a40e1de3252961125144":[1,0,4,55,57],
+"class_qt_gui_1_1_q_file_dialog.html#a97b35b542312aa25a1dca764cc22d5d5a4ee29ca12c7d126654bd0e5275de6135":[1,0,4,55,4,1],
+"class_qt_gui_1_1_q_file_dialog.html#a97b35b542312aa25a1dca764cc22d5d5aa254c25adc7d10d7e9c4889484f875a5":[1,0,4,55,4,0],
+"class_qt_gui_1_1_q_file_dialog.html#a9a6be7c5a0b4a13ddc59f9eb52036918":[1,0,4,55,40],
+"class_qt_gui_1_1_q_file_dialog.html#aa67f13bbaf21a40e1de3252961125144":[1,0,4,55,58],
 "class_qt_gui_1_1_q_file_dialog.html#aa9fd1bbde1a84e0f89c771a85a4ebf89":[1,0,4,55,24],
-"class_qt_gui_1_1_q_file_dialog.html#aac96b73d1b05f2d7bd10f37db41e5356":[1,0,4,55,27],
-"class_qt_gui_1_1_q_file_dialog.html#ab6cf27feabeb60d899393e3176e289fe":[1,0,4,55,49],
-"class_qt_gui_1_1_q_file_dialog.html#aba57dd8c6d86d20d9906e5fb4aa3e541":[1,0,4,55,55],
+"class_qt_gui_1_1_q_file_dialog.html#aac96b73d1b05f2d7bd10f37db41e5356":[1,0,4,55,28],
+"class_qt_gui_1_1_q_file_dialog.html#ab6cf27feabeb60d899393e3176e289fe":[1,0,4,55,50],
+"class_qt_gui_1_1_q_file_dialog.html#aba57dd8c6d86d20d9906e5fb4aa3e541":[1,0,4,55,56],
 "class_qt_gui_1_1_q_file_dialog.html#abfd6bf25a6c3c21a84d5dbf9d494ab6a":[1,0,4,55,22],
 "class_qt_gui_1_1_q_file_dialog.html#ac1257596b34e02c2a7734650d9a705a8":[1,0,4,55,9],
-"class_qt_gui_1_1_q_file_dialog.html#ac24bd065d74470a8821eea29b8c9440b":[1,0,4,55,28],
+"class_qt_gui_1_1_q_file_dialog.html#ac24bd065d74470a8821eea29b8c9440b":[1,0,4,55,29],
 "class_qt_gui_1_1_q_file_dialog.html#ad01314143f35184f543c8f1b62d894a9":[1,0,4,55,63],
-"class_qt_gui_1_1_q_file_dialog.html#ad0e2e84f4424224d406dc0c12f694a71":[1,0,4,55,52],
-"class_qt_gui_1_1_q_file_dialog.html#ad1e5fdacf12c1538fba4cd8c8a696f75":[1,0,4,55,45],
-"class_qt_gui_1_1_q_file_dialog.html#ad2b2c9659350f26ab2664132111e86c2":[1,0,4,55,58],
+"class_qt_gui_1_1_q_file_dialog.html#ad0e2e84f4424224d406dc0c12f694a71":[1,0,4,55,53],
+"class_qt_gui_1_1_q_file_dialog.html#ad1e5fdacf12c1538fba4cd8c8a696f75":[1,0,4,55,46],
+"class_qt_gui_1_1_q_file_dialog.html#ad2b2c9659350f26ab2664132111e86c2":[1,0,4,55,59],
 "class_qt_gui_1_1_q_file_dialog.html#ad536e82a849e28512e77d11be18916ae":[1,0,4,55,11],
-"class_qt_gui_1_1_q_file_dialog.html#ad5817250614cf4f26d4db4b73f685801":[1,0,4,55,53],
+"class_qt_gui_1_1_q_file_dialog.html#ad5817250614cf4f26d4db4b73f685801":[1,0,4,55,54],
 "class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203":[1,0,4,55,2],
-"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203":[1,0,4,55,2,0],
-"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203":[1,0,4,55,2,1],
-"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203":[1,0,4,55,2,2],
-"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203":[1,0,4,55,2,3],
-"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203":[1,0,4,55,2,4],
-"class_qt_gui_1_1_q_file_dialog.html#ae07d1ce22600e78469c46db0b34d2e2b":[1,0,4,55,26],
-"class_qt_gui_1_1_q_file_dialog.html#ae6b885fba4b0d61766de5aca7f7a5573":[1,0,4,55,44],
+"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203a78247df839e70502575b5320f2324827":[1,0,4,55,2,4],
+"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203a97801f782ea4aaf0c13f65c8305d1e3e":[1,0,4,55,2,3],
+"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203ad1c4e888c68189ea670d8b100fc8cd47":[1,0,4,55,2,0],
+"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203ae63c14ada028516a1d2acfa9578f8dce":[1,0,4,55,2,2],
+"class_qt_gui_1_1_q_file_dialog.html#ad67cfbe0d27836defa4d68ce72140203ae73cda510e8bb947f7e61089e5581494":[1,0,4,55,2,1],
+"class_qt_gui_1_1_q_file_dialog.html#ae07d1ce22600e78469c46db0b34d2e2b":[1,0,4,55,27],
+"class_qt_gui_1_1_q_file_dialog.html#ae6b885fba4b0d61766de5aca7f7a5573":[1,0,4,55,45],
 "class_qt_gui_1_1_q_file_dialog.html#aeeee3d9e5d546cfbcb2b8d58202bfa62":[1,0,4,55,25],
-"class_qt_gui_1_1_q_file_dialog.html#af33b99427e6c1d013304717889533545":[1,0,4,55,51],
-"class_qt_gui_1_1_q_file_dialog.html#af4947611ed5c7639756e5e8f8176b258":[1,0,4,55,30],
-"class_qt_gui_1_1_q_file_dialog.html#af50483bcb64ef503a2199af976e63604":[1,0,4,55,32],
-"class_qt_gui_1_1_q_file_dialog.html#af95806d5f98ba908a2122c8190038eba":[1,0,4,55,42],
+"class_qt_gui_1_1_q_file_dialog.html#af33b99427e6c1d013304717889533545":[1,0,4,55,52],
+"class_qt_gui_1_1_q_file_dialog.html#af4947611ed5c7639756e5e8f8176b258":[1,0,4,55,31],
+"class_qt_gui_1_1_q_file_dialog.html#af50483bcb64ef503a2199af976e63604":[1,0,4,55,33],
+"class_qt_gui_1_1_q_file_dialog.html#af95806d5f98ba908a2122c8190038eba":[1,0,4,55,43],
 "class_qt_gui_1_1_q_file_dialog.html#affe638a1b8077ea71590bf1bcb98425b":[1,0,4,55,19],
-"class_qt_gui_1_1_q_file_icon_provider.html":[1,0,4,56]
+"class_qt_gui_1_1_q_file_icon_provider.html":[1,0,4,56],
+"class_qt_gui_1_1_q_file_icon_provider.html#a2b1a6a6d0fd66211388a07869143e81e":[1,0,4,56,8],
+"class_qt_gui_1_1_q_file_icon_provider.html#a3b4bc30b55fa27fcdc7c26c2e3d7f6fe":[1,0,4,56,0]
 };
