@@ -1,7 +1,5 @@
 var NAVTREEINDEX59 =
 {
-"class_qt_gui_1_1_q_pixmap.html#ac694853f9600a4b078f005f0315f9b96":[1,0,4,192,61],
-"class_qt_gui_1_1_q_pixmap.html#ac6a52372ef1329e9ab7a6d314981a5b2":[1,0,4,192,56],
 "class_qt_gui_1_1_q_pixmap.html#aca1fc04851387ea797d1696f6819cdcd":[1,0,4,192,1],
 "class_qt_gui_1_1_q_pixmap.html#ad0ddc6bfcc77e2442a705674842f3ac8":[1,0,4,192,12],
 "class_qt_gui_1_1_q_pixmap.html#ad2e675eda622e8b2091f89ee136ac977":[1,0,4,192,57],
@@ -63,112 +61,112 @@ var NAVTREEINDEX59 =
 "class_qt_gui_1_1_q_plain_text_document_layout.html#adc95f5295d30162e788b156c91de4262":[1,0,4,194,2],
 "class_qt_gui_1_1_q_plain_text_document_layout.html#af38477f035576cfc6ed1a390c4b0f02d":[1,0,4,194,14],
 "class_qt_gui_1_1_q_plain_text_edit.html":[1,0,4,195],
-"class_qt_gui_1_1_q_plain_text_edit.html#a024f299c7105c334a8c132aeb830a110":[1,0,4,195,34],
-"class_qt_gui_1_1_q_plain_text_edit.html#a03a895cda82b679c8a5cf6b6558747d4":[1,0,4,195,64],
+"class_qt_gui_1_1_q_plain_text_edit.html#a024f299c7105c334a8c132aeb830a110":[1,0,4,195,35],
+"class_qt_gui_1_1_q_plain_text_edit.html#a03a895cda82b679c8a5cf6b6558747d4":[1,0,4,195,65],
 "class_qt_gui_1_1_q_plain_text_edit.html#a0665eff820de56bf76092f3392e28329":[1,0,4,195,13],
-"class_qt_gui_1_1_q_plain_text_edit.html#a07e6cbe8b925785b6b3cec99ab2c7f04":[1,0,4,195,48],
+"class_qt_gui_1_1_q_plain_text_edit.html#a07e6cbe8b925785b6b3cec99ab2c7f04":[1,0,4,195,49],
 "class_qt_gui_1_1_q_plain_text_edit.html#a09af6e1cfea4444b6a1c2cf59dffc53a":[1,0,4,195,17],
-"class_qt_gui_1_1_q_plain_text_edit.html#a0a550091325c4932ad29814bc2b2484e":[1,0,4,195,70],
+"class_qt_gui_1_1_q_plain_text_edit.html#a0a550091325c4932ad29814bc2b2484e":[1,0,4,195,71],
 "class_qt_gui_1_1_q_plain_text_edit.html#a0dac2abf0ef2ae804de4045c9fd591c3":[1,0,4,195,0],
-"class_qt_gui_1_1_q_plain_text_edit.html#a0dac2abf0ef2ae804de4045c9fd591c3":[1,0,4,195,0,0],
-"class_qt_gui_1_1_q_plain_text_edit.html#a0dac2abf0ef2ae804de4045c9fd591c3":[1,0,4,195,0,1],
-"class_qt_gui_1_1_q_plain_text_edit.html#a0ffedb6fe213b032cd5b93a9139f937c":[1,0,4,195,32],
-"class_qt_gui_1_1_q_plain_text_edit.html#a17a84f1d16a58a498184e4a9b0491f17":[1,0,4,195,71],
-"class_qt_gui_1_1_q_plain_text_edit.html#a1b59cda8b670c7e63902615a94faa0ef":[1,0,4,195,39],
-"class_qt_gui_1_1_q_plain_text_edit.html#a1c5cf6d65e5c1cb473828cc4569021b0":[1,0,4,195,74],
-"class_qt_gui_1_1_q_plain_text_edit.html#a1e4b9ba4d12f0ce852839a437fde5c07":[1,0,4,195,60],
+"class_qt_gui_1_1_q_plain_text_edit.html#a0dac2abf0ef2ae804de4045c9fd591c3a4d6fbaadc8e2495eb6384378410dbdc4":[1,0,4,195,0,1],
+"class_qt_gui_1_1_q_plain_text_edit.html#a0dac2abf0ef2ae804de4045c9fd591c3a93ac740a98eb4cc45b853c780ed16c44":[1,0,4,195,0,0],
+"class_qt_gui_1_1_q_plain_text_edit.html#a0ffedb6fe213b032cd5b93a9139f937c":[1,0,4,195,33],
+"class_qt_gui_1_1_q_plain_text_edit.html#a17a84f1d16a58a498184e4a9b0491f17":[1,0,4,195,72],
+"class_qt_gui_1_1_q_plain_text_edit.html#a1b59cda8b670c7e63902615a94faa0ef":[1,0,4,195,40],
+"class_qt_gui_1_1_q_plain_text_edit.html#a1c5cf6d65e5c1cb473828cc4569021b0":[1,0,4,195,75],
+"class_qt_gui_1_1_q_plain_text_edit.html#a1e4b9ba4d12f0ce852839a437fde5c07":[1,0,4,195,61],
 "class_qt_gui_1_1_q_plain_text_edit.html#a1eeca7ec955cab6e66afda2c6d1fd643":[1,0,4,195,103],
-"class_qt_gui_1_1_q_plain_text_edit.html#a1f992cee07b3dfbaab759ecc238cb38f":[1,0,4,195,50],
-"class_qt_gui_1_1_q_plain_text_edit.html#a205128a7a7003d33ac0c4ef91c7cec18":[1,0,4,195,80],
-"class_qt_gui_1_1_q_plain_text_edit.html#a244cf811383d178d933b4c1eb314912c":[1,0,4,195,56],
+"class_qt_gui_1_1_q_plain_text_edit.html#a1f992cee07b3dfbaab759ecc238cb38f":[1,0,4,195,51],
+"class_qt_gui_1_1_q_plain_text_edit.html#a205128a7a7003d33ac0c4ef91c7cec18":[1,0,4,195,81],
+"class_qt_gui_1_1_q_plain_text_edit.html#a244cf811383d178d933b4c1eb314912c":[1,0,4,195,57],
 "class_qt_gui_1_1_q_plain_text_edit.html#a29491f6fbde394343dc49e007cc63e81":[1,0,4,195,4],
-"class_qt_gui_1_1_q_plain_text_edit.html#a3103d815a1bd6171886a3a9e64108e29":[1,0,4,195,76],
-"class_qt_gui_1_1_q_plain_text_edit.html#a31fb66f0e17a914ef71a436535fc9041":[1,0,4,195,81],
-"class_qt_gui_1_1_q_plain_text_edit.html#a344c91b1c35dd84b38c9f1965280ef1f":[1,0,4,195,27],
-"class_qt_gui_1_1_q_plain_text_edit.html#a3584f8ecb017f92c24f847220eeda772":[1,0,4,195,75],
-"class_qt_gui_1_1_q_plain_text_edit.html#a36e58fcca60ba1fc7bf8826834b1c957":[1,0,4,195,31],
-"class_qt_gui_1_1_q_plain_text_edit.html#a3716c6f0fa23755a7bb0620b6ff21d2f":[1,0,4,195,79],
+"class_qt_gui_1_1_q_plain_text_edit.html#a3103d815a1bd6171886a3a9e64108e29":[1,0,4,195,77],
+"class_qt_gui_1_1_q_plain_text_edit.html#a31fb66f0e17a914ef71a436535fc9041":[1,0,4,195,82],
+"class_qt_gui_1_1_q_plain_text_edit.html#a344c91b1c35dd84b38c9f1965280ef1f":[1,0,4,195,28],
+"class_qt_gui_1_1_q_plain_text_edit.html#a3584f8ecb017f92c24f847220eeda772":[1,0,4,195,76],
+"class_qt_gui_1_1_q_plain_text_edit.html#a36e58fcca60ba1fc7bf8826834b1c957":[1,0,4,195,32],
+"class_qt_gui_1_1_q_plain_text_edit.html#a3716c6f0fa23755a7bb0620b6ff21d2f":[1,0,4,195,80],
 "class_qt_gui_1_1_q_plain_text_edit.html#a3c9ed799bd399294ea379923fc18a214":[1,0,4,195,20],
-"class_qt_gui_1_1_q_plain_text_edit.html#a428cac0a417d55056fe61155276bcc76":[1,0,4,195,52],
+"class_qt_gui_1_1_q_plain_text_edit.html#a428cac0a417d55056fe61155276bcc76":[1,0,4,195,53],
 "class_qt_gui_1_1_q_plain_text_edit.html#a440374bd9ad14251294b876dde7d6cd1":[1,0,4,195,12],
 "class_qt_gui_1_1_q_plain_text_edit.html#a47aca297f219e9f7b6a41d434ec52536":[1,0,4,195,94],
-"class_qt_gui_1_1_q_plain_text_edit.html#a47b159204ef3f5f9c68caa92de387fc6":[1,0,4,195,41],
+"class_qt_gui_1_1_q_plain_text_edit.html#a47b159204ef3f5f9c68caa92de387fc6":[1,0,4,195,42],
 "class_qt_gui_1_1_q_plain_text_edit.html#a4c35acdfb46861b8e97481a2b8e8c6c5":[1,0,4,195,100],
-"class_qt_gui_1_1_q_plain_text_edit.html#a4dd497129b7e804319272fad5b0b9306":[1,0,4,195,51],
-"class_qt_gui_1_1_q_plain_text_edit.html#a50f50b10ff5f97ac0fa6ab403a92a53d":[1,0,4,195,72],
-"class_qt_gui_1_1_q_plain_text_edit.html#a51c89b0afc94eff74542b13ffb8ddb51":[1,0,4,195,82],
-"class_qt_gui_1_1_q_plain_text_edit.html#a526c19dd2b67464a6f51ffa26473c002":[1,0,4,195,26],
-"class_qt_gui_1_1_q_plain_text_edit.html#a527b8af4f50ee9f6927324e66845efdf":[1,0,4,195,44],
-"class_qt_gui_1_1_q_plain_text_edit.html#a543a287fa5bc032d0f34c0ef3696bace":[1,0,4,195,33],
-"class_qt_gui_1_1_q_plain_text_edit.html#a56b008175e9dc124af79008476980f99":[1,0,4,195,49],
+"class_qt_gui_1_1_q_plain_text_edit.html#a4dd497129b7e804319272fad5b0b9306":[1,0,4,195,52],
+"class_qt_gui_1_1_q_plain_text_edit.html#a50f50b10ff5f97ac0fa6ab403a92a53d":[1,0,4,195,73],
+"class_qt_gui_1_1_q_plain_text_edit.html#a51c89b0afc94eff74542b13ffb8ddb51":[1,0,4,195,83],
+"class_qt_gui_1_1_q_plain_text_edit.html#a526c19dd2b67464a6f51ffa26473c002":[1,0,4,195,27],
+"class_qt_gui_1_1_q_plain_text_edit.html#a527b8af4f50ee9f6927324e66845efdf":[1,0,4,195,45],
+"class_qt_gui_1_1_q_plain_text_edit.html#a543a287fa5bc032d0f34c0ef3696bace":[1,0,4,195,34],
+"class_qt_gui_1_1_q_plain_text_edit.html#a56b008175e9dc124af79008476980f99":[1,0,4,195,50],
 "class_qt_gui_1_1_q_plain_text_edit.html#a59fe4aafb4d10eaf491d6ef489b87328":[1,0,4,195,98],
-"class_qt_gui_1_1_q_plain_text_edit.html#a5d5572218b8462170a7c6316c8ea077b":[1,0,4,195,30],
+"class_qt_gui_1_1_q_plain_text_edit.html#a5d5572218b8462170a7c6316c8ea077b":[1,0,4,195,31],
 "class_qt_gui_1_1_q_plain_text_edit.html#a64f43869b0bf8273a69dcc95153c11f8":[1,0,4,195,10],
 "class_qt_gui_1_1_q_plain_text_edit.html#a6730654300b3d4fc236d576f898b15b5":[1,0,4,195,102],
-"class_qt_gui_1_1_q_plain_text_edit.html#a674aaf45575e50931573c9eee32cd459":[1,0,4,195,42],
+"class_qt_gui_1_1_q_plain_text_edit.html#a674aaf45575e50931573c9eee32cd459":[1,0,4,195,43],
 "class_qt_gui_1_1_q_plain_text_edit.html#a67bcaa699fa4b87383423ba73238526e":[1,0,4,195,96],
 "class_qt_gui_1_1_q_plain_text_edit.html#a6b8c41cfc1cc963028edaf49aa242ebe":[1,0,4,195,93],
 "class_qt_gui_1_1_q_plain_text_edit.html#a72b0f034870c0cd8800e073aeff3462d":[1,0,4,195,14],
 "class_qt_gui_1_1_q_plain_text_edit.html#a734d3f3580e7b310c4fcbc54c8f15817":[1,0,4,195,97],
 "class_qt_gui_1_1_q_plain_text_edit.html#a7651090133f5daac1cf76337628f90ed":[1,0,4,195,88],
-"class_qt_gui_1_1_q_plain_text_edit.html#a769eb88ccb2c4b0e5ca534f88eab4d13":[1,0,4,195,46],
+"class_qt_gui_1_1_q_plain_text_edit.html#a769eb88ccb2c4b0e5ca534f88eab4d13":[1,0,4,195,47],
 "class_qt_gui_1_1_q_plain_text_edit.html#a7758d0d69641779e9bac41477a6010f8":[1,0,4,195,16],
 "class_qt_gui_1_1_q_plain_text_edit.html#a7881d684ff207ec307fa676cf3706f9a":[1,0,4,195,101],
-"class_qt_gui_1_1_q_plain_text_edit.html#a78ee86c5a3e3c25198c6739552fbd05c":[1,0,4,195,83],
+"class_qt_gui_1_1_q_plain_text_edit.html#a78ee86c5a3e3c25198c6739552fbd05c":[1,0,4,195,84],
 "class_qt_gui_1_1_q_plain_text_edit.html#a792cfbc8e94b20499e0fe5e497de1a30":[1,0,4,195,5],
 "class_qt_gui_1_1_q_plain_text_edit.html#a7f2d147256658eea9842b0148ac74478":[1,0,4,195,18],
 "class_qt_gui_1_1_q_plain_text_edit.html#a807307c9c261c0736fff72b99f0375cc":[1,0,4,195,8],
 "class_qt_gui_1_1_q_plain_text_edit.html#a81ca7c4ef78207e8ca1dc1db3ca55cc2":[1,0,4,195,89],
 "class_qt_gui_1_1_q_plain_text_edit.html#a82c26999f3a06b7e8e6c2f9e8f74ad94":[1,0,4,195,19],
-"class_qt_gui_1_1_q_plain_text_edit.html#a866b48aa92542dcc8e80030f4dc78473":[1,0,4,195,65],
-"class_qt_gui_1_1_q_plain_text_edit.html#a86e740ef619ef0c10bb49a86acc647ce":[1,0,4,195,63],
+"class_qt_gui_1_1_q_plain_text_edit.html#a866b48aa92542dcc8e80030f4dc78473":[1,0,4,195,66],
+"class_qt_gui_1_1_q_plain_text_edit.html#a86e740ef619ef0c10bb49a86acc647ce":[1,0,4,195,64],
 "class_qt_gui_1_1_q_plain_text_edit.html#a86eeb43889eae82e7828e52bd963f700":[1,0,4,195,1],
-"class_qt_gui_1_1_q_plain_text_edit.html#a88e8163d50753521f837e2c554c2a287":[1,0,4,195,53],
+"class_qt_gui_1_1_q_plain_text_edit.html#a88e8163d50753521f837e2c554c2a287":[1,0,4,195,54],
 "class_qt_gui_1_1_q_plain_text_edit.html#a906a4091fd40d838a1e9bdc0c20e719a":[1,0,4,195,92],
-"class_qt_gui_1_1_q_plain_text_edit.html#a95bd1935d470b2aa78acb176bbe48960":[1,0,4,195,85],
-"class_qt_gui_1_1_q_plain_text_edit.html#a95d7e01f15815896097749c00a1c1aab":[1,0,4,195,47],
-"class_qt_gui_1_1_q_plain_text_edit.html#a9fc7eb5cf10882bd89f039cc07512075":[1,0,4,195,59],
-"class_qt_gui_1_1_q_plain_text_edit.html#aa09882f36907d7208c36c45067c92169":[1,0,4,195,77],
+"class_qt_gui_1_1_q_plain_text_edit.html#a95d7e01f15815896097749c00a1c1aab":[1,0,4,195,48],
+"class_qt_gui_1_1_q_plain_text_edit.html#a9fc7eb5cf10882bd89f039cc07512075":[1,0,4,195,60],
+"class_qt_gui_1_1_q_plain_text_edit.html#aa09882f36907d7208c36c45067c92169":[1,0,4,195,78],
 "class_qt_gui_1_1_q_plain_text_edit.html#aa0bc9e0a4df2760e9a2de067de8698fd":[1,0,4,195,11],
-"class_qt_gui_1_1_q_plain_text_edit.html#aa0d871bc72d409d4cb825dcc494b316f":[1,0,4,195,58],
+"class_qt_gui_1_1_q_plain_text_edit.html#aa0d871bc72d409d4cb825dcc494b316f":[1,0,4,195,59],
 "class_qt_gui_1_1_q_plain_text_edit.html#aa1d070e0dbf2760a2576604bea1161dc":[1,0,4,195,91],
 "class_qt_gui_1_1_q_plain_text_edit.html#aa3941c85d1e702b2cb7089add7e06af4":[1,0,4,195,95],
-"class_qt_gui_1_1_q_plain_text_edit.html#aa3a80aaca97d5d52b413193da8bf7159":[1,0,4,195,43],
-"class_qt_gui_1_1_q_plain_text_edit.html#aa489d61b17cce84cfe0939945d44ab3b":[1,0,4,195,62],
-"class_qt_gui_1_1_q_plain_text_edit.html#aa675c6ca58a5431fc019a9014a696056":[1,0,4,195,68],
-"class_qt_gui_1_1_q_plain_text_edit.html#aa9439ad61758b776fc4e028a7fff3f3f":[1,0,4,195,55],
-"class_qt_gui_1_1_q_plain_text_edit.html#aa9a7951f2f78a2c113bce3cbec8fdd1a":[1,0,4,195,38],
-"class_qt_gui_1_1_q_plain_text_edit.html#ab123322670d192d59684e4fa6b9a4ea8":[1,0,4,195,69],
-"class_qt_gui_1_1_q_plain_text_edit.html#ab234f81fbd4e713203d139932800ff11":[1,0,4,195,67],
-"class_qt_gui_1_1_q_plain_text_edit.html#ab340236ba9b11ceeb6272d8214dfb0a4":[1,0,4,195,29],
+"class_qt_gui_1_1_q_plain_text_edit.html#aa3a80aaca97d5d52b413193da8bf7159":[1,0,4,195,44],
+"class_qt_gui_1_1_q_plain_text_edit.html#aa489d61b17cce84cfe0939945d44ab3b":[1,0,4,195,63],
+"class_qt_gui_1_1_q_plain_text_edit.html#aa675c6ca58a5431fc019a9014a696056":[1,0,4,195,69],
+"class_qt_gui_1_1_q_plain_text_edit.html#aa9439ad61758b776fc4e028a7fff3f3f":[1,0,4,195,56],
+"class_qt_gui_1_1_q_plain_text_edit.html#aa9a7951f2f78a2c113bce3cbec8fdd1a":[1,0,4,195,39],
+"class_qt_gui_1_1_q_plain_text_edit.html#ab123322670d192d59684e4fa6b9a4ea8":[1,0,4,195,70],
+"class_qt_gui_1_1_q_plain_text_edit.html#ab234f81fbd4e713203d139932800ff11":[1,0,4,195,68],
+"class_qt_gui_1_1_q_plain_text_edit.html#ab340236ba9b11ceeb6272d8214dfb0a4":[1,0,4,195,30],
 "class_qt_gui_1_1_q_plain_text_edit.html#ab497b192a9af560c2af54ec17a382836":[1,0,4,195,7],
 "class_qt_gui_1_1_q_plain_text_edit.html#ab5d984aad8daba483c5d23eaaa1dc597":[1,0,4,195,15],
-"class_qt_gui_1_1_q_plain_text_edit.html#ab5f9ad2107890055357c068ec5a15b3e":[1,0,4,195,28],
+"class_qt_gui_1_1_q_plain_text_edit.html#ab5f9ad2107890055357c068ec5a15b3e":[1,0,4,195,29],
 "class_qt_gui_1_1_q_plain_text_edit.html#ab93f1d99099fcbdcef7f38f2d16fff1b":[1,0,4,195,99],
-"class_qt_gui_1_1_q_plain_text_edit.html#abee2aa47a86d1c9ffe5e9896111de1fb":[1,0,4,195,84],
+"class_qt_gui_1_1_q_plain_text_edit.html#abee2aa47a86d1c9ffe5e9896111de1fb":[1,0,4,195,85],
 "class_qt_gui_1_1_q_plain_text_edit.html#ac2b88fc33588ce55407243f8a95271ef":[1,0,4,195,3],
-"class_qt_gui_1_1_q_plain_text_edit.html#acbfb544ff6e5f86ed54c89943e5aa1cf":[1,0,4,195,37],
+"class_qt_gui_1_1_q_plain_text_edit.html#acbfb544ff6e5f86ed54c89943e5aa1cf":[1,0,4,195,38],
 "class_qt_gui_1_1_q_plain_text_edit.html#ace8da1f5b00b68b3e70e8dfa187f9dd2":[1,0,4,195,22],
-"class_qt_gui_1_1_q_plain_text_edit.html#acfa319e57ef205be276a18ae3b6ae8a1":[1,0,4,195,57],
+"class_qt_gui_1_1_q_plain_text_edit.html#acfa319e57ef205be276a18ae3b6ae8a1":[1,0,4,195,58],
 "class_qt_gui_1_1_q_plain_text_edit.html#ad0e0376d5773caba3fbd4d4d1da29ba0":[1,0,4,195,6],
 "class_qt_gui_1_1_q_plain_text_edit.html#ad3d37cdc720e84cb048cd1b11a91ac9e":[1,0,4,195,87],
-"class_qt_gui_1_1_q_plain_text_edit.html#ad8914977550252d95ef4ef9c9d5a1002":[1,0,4,195,54],
+"class_qt_gui_1_1_q_plain_text_edit.html#ad8914977550252d95ef4ef9c9d5a1002":[1,0,4,195,55],
 "class_qt_gui_1_1_q_plain_text_edit.html#adb5933e805e6c0e301324011c546e48e":[1,0,4,195,9],
-"class_qt_gui_1_1_q_plain_text_edit.html#adf16d36b591dd868fdbc9534043f09fa":[1,0,4,195,61],
+"class_qt_gui_1_1_q_plain_text_edit.html#adf16d36b591dd868fdbc9534043f09fa":[1,0,4,195,62],
 "class_qt_gui_1_1_q_plain_text_edit.html#ae2d7db58048b34e46c0e02212a99a5ea":[1,0,4,195,24],
 "class_qt_gui_1_1_q_plain_text_edit.html#ae588b55f5764730ed9c99fc733157772":[1,0,4,195,23],
 "class_qt_gui_1_1_q_plain_text_edit.html#ae853f663001570adb43c4699d57e71d3":[1,0,4,195,21],
 "class_qt_gui_1_1_q_plain_text_edit.html#aea765093fdaae8da1e1cad1976b119c4":[1,0,4,195,90],
-"class_qt_gui_1_1_q_plain_text_edit.html#aeb09f6a6c5c8e6ed5db347101a62f97f":[1,0,4,195,66],
+"class_qt_gui_1_1_q_plain_text_edit.html#aeb09f6a6c5c8e6ed5db347101a62f97f":[1,0,4,195,67],
+"class_qt_gui_1_1_q_plain_text_edit.html#aeb945eebf8a0f4176fa5082d854d92b7":[1,0,4,195,25],
 "class_qt_gui_1_1_q_plain_text_edit.html#aee87e3fb328dec469b5042eeabcc0018":[1,0,4,195,86],
-"class_qt_gui_1_1_q_plain_text_edit.html#aee9d3c218e6276b27d959859168bf85b":[1,0,4,195,73],
-"class_qt_gui_1_1_q_plain_text_edit.html#af36c0b9132e8beaf24687adacd2ceee7":[1,0,4,195,36],
-"class_qt_gui_1_1_q_plain_text_edit.html#af453b873c648a35a2b4142fba62babed":[1,0,4,195,25],
-"class_qt_gui_1_1_q_plain_text_edit.html#af4572c1d0b9879d4fea4440632253dd0":[1,0,4,195,45],
-"class_qt_gui_1_1_q_plain_text_edit.html#af7bc5390109fbe9234b32c5e5dda7a0c":[1,0,4,195,40],
-"class_qt_gui_1_1_q_plain_text_edit.html#af7c5b9d6dc2675c48e5ef979dbc2eeaa":[1,0,4,195,78],
+"class_qt_gui_1_1_q_plain_text_edit.html#aee9d3c218e6276b27d959859168bf85b":[1,0,4,195,74],
+"class_qt_gui_1_1_q_plain_text_edit.html#af36c0b9132e8beaf24687adacd2ceee7":[1,0,4,195,37],
+"class_qt_gui_1_1_q_plain_text_edit.html#af453b873c648a35a2b4142fba62babed":[1,0,4,195,26],
+"class_qt_gui_1_1_q_plain_text_edit.html#af4572c1d0b9879d4fea4440632253dd0":[1,0,4,195,46],
+"class_qt_gui_1_1_q_plain_text_edit.html#af7bc5390109fbe9234b32c5e5dda7a0c":[1,0,4,195,41],
+"class_qt_gui_1_1_q_plain_text_edit.html#af7c5b9d6dc2675c48e5ef979dbc2eeaa":[1,0,4,195,79],
 "class_qt_gui_1_1_q_plain_text_edit.html#af9d9ee33aefcf7a3b6ca3d9f130ad5a8":[1,0,4,195,2],
-"class_qt_gui_1_1_q_plain_text_edit.html#afa53082346ca8d072ead8f77c2dfabda":[1,0,4,195,35],
+"class_qt_gui_1_1_q_plain_text_edit.html#afa53082346ca8d072ead8f77c2dfabda":[1,0,4,195,36],
 "class_qt_gui_1_1_q_polygon.html":[1,0,4,196],
 "class_qt_gui_1_1_q_polygon.html#a04209f30041b9e63955181434a340355":[1,0,4,196,12],
 "class_qt_gui_1_1_q_polygon.html#a077a9e4486714956737d0c88c526bc43":[1,0,4,196,7],
@@ -249,5 +247,7 @@ var NAVTREEINDEX59 =
 "class_qt_gui_1_1_q_print_dialog.html#ae5a645b0a01a844dd90c4750c29ff057":[1,0,4,198,4],
 "class_qt_gui_1_1_q_print_dialog.html#ae7932b57b738fbd54166464c5bd0cf60":[1,0,4,198,0],
 "class_qt_gui_1_1_q_print_dialog.html#aeb626a6e466af3ff5694d0365ef38a59":[1,0,4,198,6],
-"class_qt_gui_1_1_q_print_engine.html":[1,0,4,199]
+"class_qt_gui_1_1_q_print_engine.html":[1,0,4,199],
+"class_qt_gui_1_1_q_print_engine.html#a0c9c123703a9cc915558085f68083655":[1,0,4,199,8],
+"class_qt_gui_1_1_q_print_engine.html#a0d1a03590ec83268855e37b34b0f205b":[1,0,4,199,15]
 };
