@@ -1,7 +1,5 @@
 var NAVTREEINDEX61 =
 {
-"class_qt_gui_1_1_q_printer.html#afc7e8d2ba1e9af1227ef8fe553474dd0":[1,0,4,202,0,0],
-"class_qt_gui_1_1_q_printer_info.html":[1,0,4,203],
 "class_qt_gui_1_1_q_printer_info.html#a234d87b81db1b27fc9220495c42f686a":[1,0,4,203,5],
 "class_qt_gui_1_1_q_printer_info.html#a2c48a1111f38370b69148b04075d1917":[1,0,4,203,0],
 "class_qt_gui_1_1_q_printer_info.html#a2ddac062b8a888525ce35bbd60bd9a9b":[1,0,4,203,9],
@@ -18,10 +16,9 @@ var NAVTREEINDEX61 =
 "class_qt_gui_1_1_q_printer_info.html#afcf08ba2e4be3141660b4305899609e0":[1,0,4,203,10],
 "class_qt_gui_1_1_q_progress_bar.html":[1,0,4,204],
 "class_qt_gui_1_1_q_progress_bar.html#a083b5e12340ba795b684cd660dca0237":[1,0,4,204,10],
-"class_qt_gui_1_1_q_progress_bar.html#a0ad3b0d663a94f24e9f0903aefd765da":[1,0,4,204,25],
-"class_qt_gui_1_1_q_progress_bar.html#a1de9742d15c8a25a4215499cc0d29676":[1,0,4,204,0,0],
 "class_qt_gui_1_1_q_progress_bar.html#a1de9742d15c8a25a4215499cc0d29676":[1,0,4,204,0],
-"class_qt_gui_1_1_q_progress_bar.html#a1de9742d15c8a25a4215499cc0d29676":[1,0,4,204,0,1],
+"class_qt_gui_1_1_q_progress_bar.html#a1de9742d15c8a25a4215499cc0d29676a63dc349be51108dcfd197c7ab02b486a":[1,0,4,204,0,0],
+"class_qt_gui_1_1_q_progress_bar.html#a1de9742d15c8a25a4215499cc0d29676af2b1a19a8d0f523d042f9ede79a80804":[1,0,4,204,0,1],
 "class_qt_gui_1_1_q_progress_bar.html#a278693cd7399b59c1292e1c0ae0a10f9":[1,0,4,204,12],
 "class_qt_gui_1_1_q_progress_bar.html#a354ce4fe360910f9ddc0096da955a633":[1,0,4,204,29],
 "class_qt_gui_1_1_q_progress_bar.html#a3a38dc5991881f81d959bd8e2faf6787":[1,0,4,204,21],
@@ -48,6 +45,7 @@ var NAVTREEINDEX61 =
 "class_qt_gui_1_1_q_progress_bar.html#aed20437a93469188b45849db2f29e1d4":[1,0,4,204,6],
 "class_qt_gui_1_1_q_progress_bar.html#aef0a7b95db5cf6149628ac9d76dbee40":[1,0,4,204,7],
 "class_qt_gui_1_1_q_progress_bar.html#af0e5f2b0e3ad4dc1c381032e09e09b86":[1,0,4,204,14],
+"class_qt_gui_1_1_q_progress_bar.html#afe1cbf97fc82e44d495ad9cb17f38da3":[1,0,4,204,25],
 "class_qt_gui_1_1_q_progress_bar.html#afe66ed62e25dc3dfe6cc1f12bf3d1c4f":[1,0,4,204,5],
 "class_qt_gui_1_1_q_progress_dialog.html":[1,0,4,205],
 "class_qt_gui_1_1_q_progress_dialog.html#a185715b52e25501c2d9165cfb74cc07d":[1,0,4,205,15],
@@ -249,5 +247,7 @@ var NAVTREEINDEX61 =
 "class_qt_gui_1_1_q_radial_gradient.html#a9730919c63de1a4da3d4b5e2a1758693":[1,0,4,210,8],
 "class_qt_gui_1_1_q_radial_gradient.html#aa94a3a68e5634390bb9f2780ee591bc5":[1,0,4,210,11],
 "class_qt_gui_1_1_q_radial_gradient.html#ab3f73d68da71287175ce398beab12a9b":[1,0,4,210,16],
-"class_qt_gui_1_1_q_radial_gradient.html#ab9189006478125a1401e0b0d0570c6e4":[1,0,4,210,4]
+"class_qt_gui_1_1_q_radial_gradient.html#ab9189006478125a1401e0b0d0570c6e4":[1,0,4,210,4],
+"class_qt_gui_1_1_q_radial_gradient.html#ac8396a2e5a7a9d3db591c3fc4a26ddac":[1,0,4,210,0],
+"class_qt_gui_1_1_q_radial_gradient.html#ae3781c4fcade652e6d4bc544d69d695b":[1,0,4,210,3]
 };
