@@ -1,7 +1,5 @@
 var NAVTREEINDEX78 =
 {
-"class_qt_gui_1_1_q_text_table_format.html":[1,0,4,327],
-"class_qt_gui_1_1_q_text_table_format.html#a2b75ff13fadf12d781a533a1a89aa87b":[1,0,4,327,10],
 "class_qt_gui_1_1_q_text_table_format.html#a300ba682e9a2d26fee9f0cfe80e9e49e":[1,0,4,327,11],
 "class_qt_gui_1_1_q_text_table_format.html#a3d6508b8f2a93b137939d160da2ddcb5":[1,0,4,327,7],
 "class_qt_gui_1_1_q_text_table_format.html#a754b64ca17abcb91d893845acc439bae":[1,0,4,327,0],
@@ -164,10 +162,10 @@ var NAVTREEINDEX78 =
 "class_qt_gui_1_1_q_tool_button.html#ab88b540913f4711bbede45c20752c33c":[1,0,4,333,18],
 "class_qt_gui_1_1_q_tool_button.html#ac6bfe5afae66e845fae155d4fdd40961":[1,0,4,333,3],
 "class_qt_gui_1_1_q_tool_button.html#acb483b3212851a89a78758285bd382f2":[1,0,4,333,17],
-"class_qt_gui_1_1_q_tool_button.html#ad16e1ae0706cbbb84ff522c38b36c5d0":[1,0,4,333,0,2],
-"class_qt_gui_1_1_q_tool_button.html#ad16e1ae0706cbbb84ff522c38b36c5d0":[1,0,4,333,0,0],
-"class_qt_gui_1_1_q_tool_button.html#ad16e1ae0706cbbb84ff522c38b36c5d0":[1,0,4,333,0,1],
 "class_qt_gui_1_1_q_tool_button.html#ad16e1ae0706cbbb84ff522c38b36c5d0":[1,0,4,333,0],
+"class_qt_gui_1_1_q_tool_button.html#ad16e1ae0706cbbb84ff522c38b36c5d0a00b2973bffc8ed6c4d72245afe298125":[1,0,4,333,0,0],
+"class_qt_gui_1_1_q_tool_button.html#ad16e1ae0706cbbb84ff522c38b36c5d0a6a9dea7a977cba0dc2ccddda8f5c394e":[1,0,4,333,0,1],
+"class_qt_gui_1_1_q_tool_button.html#ad16e1ae0706cbbb84ff522c38b36c5d0af5c6918e68f17768e1313ef8317ec7d0":[1,0,4,333,0,2],
 "class_qt_gui_1_1_q_tool_button.html#ad5097201ec77854879b831fce823361b":[1,0,4,333,26],
 "class_qt_gui_1_1_q_tool_button.html#ad84319cff9331de3925d1ac16d43992f":[1,0,4,333,19],
 "class_qt_gui_1_1_q_tool_button.html#ade6a1809b529c24e60f449cd92fd92b9":[1,0,4,333,32],
@@ -198,8 +196,8 @@ var NAVTREEINDEX78 =
 "class_qt_gui_1_1_q_touch_event.html#a516561d12cf852ac336758a42c848cbe":[1,0,4,335,14],
 "class_qt_gui_1_1_q_touch_event.html#a5393c6c5dd1aa5898b4e2e8c1d55d48c":[1,0,4,335,12],
 "class_qt_gui_1_1_q_touch_event.html#a86044093e2a9f60cfef0443c1bd2020f":[1,0,4,335,1],
-"class_qt_gui_1_1_q_touch_event.html#a86044093e2a9f60cfef0443c1bd2020f":[1,0,4,335,1,0],
-"class_qt_gui_1_1_q_touch_event.html#a86044093e2a9f60cfef0443c1bd2020f":[1,0,4,335,1,1],
+"class_qt_gui_1_1_q_touch_event.html#a86044093e2a9f60cfef0443c1bd2020fa2817f8d374c20bb60866595401f83f15":[1,0,4,335,1,0],
+"class_qt_gui_1_1_q_touch_event.html#a86044093e2a9f60cfef0443c1bd2020fa64a952e5a8456c1030ce54bfa07ebb52":[1,0,4,335,1,1],
 "class_qt_gui_1_1_q_touch_event.html#a900413c916b794886adacd133fd21a2a":[1,0,4,335,5],
 "class_qt_gui_1_1_q_touch_event.html#a948199c38e76b3a84663520c9cca5d28":[1,0,4,335,10],
 "class_qt_gui_1_1_q_touch_event.html#ab87ecf7717581ded024e910933fe955c":[1,0,4,335,8],
@@ -241,13 +239,15 @@ var NAVTREEINDEX78 =
 "class_qt_gui_1_1_q_transform.html#a0d79065d97e26bbde60daafd7a6804a8":[1,0,4,336,1],
 "class_qt_gui_1_1_q_transform.html#a105da58750535f07683e5c5ac830ba01":[1,0,4,336,27],
 "class_qt_gui_1_1_q_transform.html#a12df98207dc14b89c1adcf0d2648d322":[1,0,4,336,40],
-"class_qt_gui_1_1_q_transform.html#a13bb64d423b3c0f96ab5314ac5f7827f":[1,0,4,336,49],
-"class_qt_gui_1_1_q_transform.html#a1541621d95bb236fe9a4f1c1e1666146":[1,0,4,336,52],
-"class_qt_gui_1_1_q_transform.html#a180cf44cdd226f0eccbdc4baedb22c10":[1,0,4,336,56],
+"class_qt_gui_1_1_q_transform.html#a13bb64d423b3c0f96ab5314ac5f7827f":[1,0,4,336,48],
+"class_qt_gui_1_1_q_transform.html#a1541621d95bb236fe9a4f1c1e1666146":[1,0,4,336,51],
+"class_qt_gui_1_1_q_transform.html#a180cf44cdd226f0eccbdc4baedb22c10":[1,0,4,336,55],
 "class_qt_gui_1_1_q_transform.html#a1bf2747980f9df378c2fc8029cab730e":[1,0,4,336,25],
-"class_qt_gui_1_1_q_transform.html#a2a40ee8501658e58a6d1823942dc1694":[1,0,4,336,58],
-"class_qt_gui_1_1_q_transform.html#a2c17826744d7ff5765f1070894ff5255":[1,0,4,336,57],
+"class_qt_gui_1_1_q_transform.html#a2a40ee8501658e58a6d1823942dc1694":[1,0,4,336,57],
+"class_qt_gui_1_1_q_transform.html#a2c17826744d7ff5765f1070894ff5255":[1,0,4,336,56],
 "class_qt_gui_1_1_q_transform.html#a2c90ab8fa609da56b2e5999077204969":[1,0,4,336,39],
-"class_qt_gui_1_1_q_transform.html#a2d459e125adfc16ea495a7e900785de7":[1,0,4,336,47],
-"class_qt_gui_1_1_q_transform.html#a2f60db6220c36ea28ed5945efe78b4d7":[1,0,4,336,43]
+"class_qt_gui_1_1_q_transform.html#a2f60db6220c36ea28ed5945efe78b4d7":[1,0,4,336,43],
+"class_qt_gui_1_1_q_transform.html#a30c9530c5c41300a7cab6788e456f892":[1,0,4,336,34],
+"class_qt_gui_1_1_q_transform.html#a321d5fa41d37f7fc4c5244d5e1571adc":[1,0,4,336,14],
+"class_qt_gui_1_1_q_transform.html#a32cc7f83f2b9cd66020b8fb96184f527":[1,0,4,336,62]
 };
