@@ -1,64 +1,62 @@
 var NAVTREEINDEX79 =
 {
-"class_qt_gui_1_1_q_transform.html#a30c9530c5c41300a7cab6788e456f892":[1,0,4,336,34],
-"class_qt_gui_1_1_q_transform.html#a321d5fa41d37f7fc4c5244d5e1571adc":[1,0,4,336,14],
-"class_qt_gui_1_1_q_transform.html#a32cc7f83f2b9cd66020b8fb96184f527":[1,0,4,336,63],
 "class_qt_gui_1_1_q_transform.html#a3d13c028815398d6c1862691d74ad2f8":[1,0,4,336,70],
 "class_qt_gui_1_1_q_transform.html#a45e9eed83860f91d7fe7996d8edd939a":[1,0,4,336,5],
 "class_qt_gui_1_1_q_transform.html#a46b29bc7b4967c6cbaf97a1a5c902a4f":[1,0,4,336,24],
 "class_qt_gui_1_1_q_transform.html#a491370a834745957b741a00e85e0faf7":[1,0,4,336,8],
-"class_qt_gui_1_1_q_transform.html#a4b28798b6e8de724689fdbee15135738":[1,0,4,336,54],
+"class_qt_gui_1_1_q_transform.html#a4b28798b6e8de724689fdbee15135738":[1,0,4,336,53],
 "class_qt_gui_1_1_q_transform.html#a4c7aec1c5eb5d4a30e8591dcb5703da5":[1,0,4,336,33],
-"class_qt_gui_1_1_q_transform.html#a4f9efddd876be0b7dbcdf26840b73112":[1,0,4,336,60],
+"class_qt_gui_1_1_q_transform.html#a4f9efddd876be0b7dbcdf26840b73112":[1,0,4,336,59],
 "class_qt_gui_1_1_q_transform.html#a516ef70d1cdb69f8fe9ef8564992f737":[1,0,4,336,46],
 "class_qt_gui_1_1_q_transform.html#a520bd34f6868ba97a0077b2f08ff8454":[1,0,4,336,11],
 "class_qt_gui_1_1_q_transform.html#a5c13e879ddb5adfdb9b662bf78a23fc2":[1,0,4,336,21],
-"class_qt_gui_1_1_q_transform.html#a6242671b1dd288003e5997a07b4834ac":[1,0,4,336,68],
-"class_qt_gui_1_1_q_transform.html#a63b826e83ddae68e4aca3bf73dc050bd":[1,0,4,336,69],
+"class_qt_gui_1_1_q_transform.html#a6242671b1dd288003e5997a07b4834ac":[1,0,4,336,67],
+"class_qt_gui_1_1_q_transform.html#a63b826e83ddae68e4aca3bf73dc050bd":[1,0,4,336,68],
 "class_qt_gui_1_1_q_transform.html#a64cdac3264be69d3493f49833793aaa2":[1,0,4,336,18],
 "class_qt_gui_1_1_q_transform.html#a6929774501fdd30e1f28c34a06d1333f":[1,0,4,336,36],
 "class_qt_gui_1_1_q_transform.html#a6a17cec6c4fe02345c60f34c3f3519da":[1,0,4,336,7],
 "class_qt_gui_1_1_q_transform.html#a6bec2f1a161d18c7a854ca9bf279bf79":[1,0,4,336,45],
 "class_qt_gui_1_1_q_transform.html#a6faa1e34cbde7e66e6cab0d9395c70e1":[1,0,4,336,31],
-"class_qt_gui_1_1_q_transform.html#a6fe7ca02933b42e4e3cc9087fc19ffe3":[1,0,4,336,55],
+"class_qt_gui_1_1_q_transform.html#a6fe7ca02933b42e4e3cc9087fc19ffe3":[1,0,4,336,54],
+"class_qt_gui_1_1_q_transform.html#a71b51209dfbc62ce5e64a145260af344":[1,0,4,336,69],
 "class_qt_gui_1_1_q_transform.html#a759a4230af2f7b6aa8841f88705650e6":[1,0,4,336,32],
-"class_qt_gui_1_1_q_transform.html#a78efe68e1a443b9aba2ea3e24867d581":[1,0,4,336,50],
-"class_qt_gui_1_1_q_transform.html#a79952c17181d020d96f1b09ca8a8c7a2":[1,0,4,336,67],
+"class_qt_gui_1_1_q_transform.html#a78efe68e1a443b9aba2ea3e24867d581":[1,0,4,336,49],
+"class_qt_gui_1_1_q_transform.html#a79952c17181d020d96f1b09ca8a8c7a2":[1,0,4,336,66],
 "class_qt_gui_1_1_q_transform.html#a7a4f6888700afbab352a607b04913db2":[1,0,4,336,19],
-"class_qt_gui_1_1_q_transform.html#a7cab8ff8055c8714a7c1db1da6d5adf1":[1,0,4,336,59],
+"class_qt_gui_1_1_q_transform.html#a7cab8ff8055c8714a7c1db1da6d5adf1":[1,0,4,336,58],
 "class_qt_gui_1_1_q_transform.html#a827780cef765551a6b20ed553d7bd46c":[1,0,4,336,29],
-"class_qt_gui_1_1_q_transform.html#a84e0d1dc6b51a01de712fdd52c14dc7f":[1,0,4,336,64],
-"class_qt_gui_1_1_q_transform.html#a86e94502bc507e7b9023d367df28937d":[1,0,4,336,48],
+"class_qt_gui_1_1_q_transform.html#a84e0d1dc6b51a01de712fdd52c14dc7f":[1,0,4,336,63],
+"class_qt_gui_1_1_q_transform.html#a86e94502bc507e7b9023d367df28937d":[1,0,4,336,47],
 "class_qt_gui_1_1_q_transform.html#a895a15c0386c2e38cb76a93d29806340":[1,0,4,336,38],
-"class_qt_gui_1_1_q_transform.html#a8de98a311a3cf68d76bef3ea1f79c800":[1,0,4,336,53],
+"class_qt_gui_1_1_q_transform.html#a8de98a311a3cf68d76bef3ea1f79c800":[1,0,4,336,52],
 "class_qt_gui_1_1_q_transform.html#a94184bf92e60df0573f1d896be0ef01f":[1,0,4,336,3],
-"class_qt_gui_1_1_q_transform.html#a9791bc5df9f75c1c898d5808f7051a62":[1,0,4,336,66],
+"class_qt_gui_1_1_q_transform.html#a9791bc5df9f75c1c898d5808f7051a62":[1,0,4,336,65],
 "class_qt_gui_1_1_q_transform.html#a9d3a65dd1f27e4f60cb2c522e3aab695":[1,0,4,336,10],
-"class_qt_gui_1_1_q_transform.html#a9e4c9ab3c50ac07ba78e6e6a79e2bfcb":[1,0,4,336,61],
+"class_qt_gui_1_1_q_transform.html#a9e4c9ab3c50ac07ba78e6e6a79e2bfcb":[1,0,4,336,60],
 "class_qt_gui_1_1_q_transform.html#a9f896aa3df6c5585ced4b044c7bf48ef":[1,0,4,336,28],
 "class_qt_gui_1_1_q_transform.html#a9fb19d2e8c5104e1cfc4032151ac3b3e":[1,0,4,336,16],
 "class_qt_gui_1_1_q_transform.html#aa3dc3c2648b2763f73d0ce4f2a2ec04f":[1,0,4,336,2],
-"class_qt_gui_1_1_q_transform.html#aa665855140c5f1a27793b2fdf8de22ba":[1,0,4,336,51],
+"class_qt_gui_1_1_q_transform.html#aa665855140c5f1a27793b2fdf8de22ba":[1,0,4,336,50],
 "class_qt_gui_1_1_q_transform.html#aa9dab1b32516902da21aef2a006b6255":[1,0,4,336,13],
 "class_qt_gui_1_1_q_transform.html#aad3180ff9f93184fa539c7c87bb1c755":[1,0,4,336,41],
 "class_qt_gui_1_1_q_transform.html#ab3c87de4728d7c00ce59b2beab0cd6cf":[1,0,4,336,4],
 "class_qt_gui_1_1_q_transform.html#ab4125e3a0704dbd38948c454280fcb07":[1,0,4,336,23],
 "class_qt_gui_1_1_q_transform.html#abe420d5b00bed576c90bccff2df8c37a":[1,0,4,336,12],
-"class_qt_gui_1_1_q_transform.html#ac56749a176c0f07c4ce6b29e281d6217":[1,0,4,336,65],
+"class_qt_gui_1_1_q_transform.html#ac56749a176c0f07c4ce6b29e281d6217":[1,0,4,336,64],
 "class_qt_gui_1_1_q_transform.html#aca119e514b26a66ac4915244469a31a2":[1,0,4,336,15],
 "class_qt_gui_1_1_q_transform.html#acd696ac54677f0de575b7a295f7e4899":[1,0,4,336,35],
 "class_qt_gui_1_1_q_transform.html#acf1cf61578a696f1f0874656de207019":[1,0,4,336,44],
 "class_qt_gui_1_1_q_transform.html#ad0088610ecd0f1f92912962776f45f56":[1,0,4,336,20],
 "class_qt_gui_1_1_q_transform.html#ad9a1710289a7921f39823c7ca141c4cc":[1,0,4,336,17],
 "class_qt_gui_1_1_q_transform.html#adbcd7095cbe54039ace530f1a0ba5da5":[1,0,4,336,30],
-"class_qt_gui_1_1_q_transform.html#ae036653f5870ae01b162906703be3fea":[1,0,4,336,62],
-"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303":[1,0,4,336,0,1],
-"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303":[1,0,4,336,0,5],
-"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303":[1,0,4,336,0,4],
+"class_qt_gui_1_1_q_transform.html#ae036653f5870ae01b162906703be3fea":[1,0,4,336,61],
 "class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303":[1,0,4,336,0],
-"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303":[1,0,4,336,0,0],
-"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303":[1,0,4,336,0,3],
-"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303":[1,0,4,336,0,2],
+"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303a1827de64337979db0aecc72afc5ad376":[1,0,4,336,0,1],
+"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303a40be82fe956f2d31fbdc0c6979a06233":[1,0,4,336,0,4],
+"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303a712ca67c9b78cee1e4ce2a6694706569":[1,0,4,336,0,2],
+"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303aa04433eb533bca79ca39358edf5bf331":[1,0,4,336,0,0],
+"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303ac74b301d87257154fd17bee4c817918a":[1,0,4,336,0,3],
+"class_qt_gui_1_1_q_transform.html#ae88ac9cf0cbcf2fc0c16bffaee9c1303aca1520d243a0ad799a54e41ef99e184d":[1,0,4,336,0,5],
 "class_qt_gui_1_1_q_transform.html#aec0d4cf08e819eb7a32a78162677455b":[1,0,4,336,6],
 "class_qt_gui_1_1_q_transform.html#af1c8de925f1e0d416890b479a685443d":[1,0,4,336,26],
 "class_qt_gui_1_1_q_transform.html#af8ad32d2d3a3ea4fa96cdfb7a6845eec":[1,0,4,336,42],
@@ -249,5 +247,7 @@ var NAVTREEINDEX79 =
 "class_qt_gui_1_1_q_tree_widget.html#afcef383ef87747a1f3d8a2e5d2bae9d5":[1,0,4,338,32],
 "class_qt_gui_1_1_q_tree_widget_item.html":[1,0,4,339],
 "class_qt_gui_1_1_q_tree_widget_item.html#a06026d80a0c276527348bbd93ccb8368":[1,0,4,339,11],
-"class_qt_gui_1_1_q_tree_widget_item.html#a068faac72f46eb4420195abe112266c0":[1,0,4,339,1]
+"class_qt_gui_1_1_q_tree_widget_item.html#a068faac72f46eb4420195abe112266c0":[1,0,4,339,1],
+"class_qt_gui_1_1_q_tree_widget_item.html#a068faac72f46eb4420195abe112266c0a336c669dc04e827c6fa15cdfc5a64e7d":[1,0,4,339,1,1],
+"class_qt_gui_1_1_q_tree_widget_item.html#a068faac72f46eb4420195abe112266c0aa1fa27779242b4902f7ae3bdd5c6d508":[1,0,4,339,1,0]
 };
