@@ -1,19 +1,25 @@
 var NAVTREEINDEX99 =
 {
-"class_qt_web_kit_1_1_q_web_element_collection.html#a2f1289740bae6b05c49d0a26aefbc0a4":[1,0,11,2,12],
+"class_qt_web_kit_1_1_q_web_database.html#ab6113b59769527b6ed4cce2101fe4486":[1,0,11,1,7],
+"class_qt_web_kit_1_1_q_web_database.html#ae94823bb53f923ad61adb7d9c8d99673":[1,0,11,1,8],
+"class_qt_web_kit_1_1_q_web_element_collection.html":[1,0,11,2],
+"class_qt_web_kit_1_1_q_web_element_collection.html#a0e2cc5aeaff1b662668f2b00f904a4cb":[1,0,11,2,9],
+"class_qt_web_kit_1_1_q_web_element_collection.html#a1179871e65735b81c18befd38a91f29f":[1,0,11,2,19],
+"class_qt_web_kit_1_1_q_web_element_collection.html#a121a8117e560eee0495649ae651c3159":[1,0,11,2,7],
+"class_qt_web_kit_1_1_q_web_element_collection.html#a2f1289740bae6b05c49d0a26aefbc0a4":[1,0,11,2,13],
 "class_qt_web_kit_1_1_q_web_element_collection.html#a4169380b2048014ca1277dddeac72eae":[1,0,11,2,4],
 "class_qt_web_kit_1_1_q_web_element_collection.html#a449abb70c65b15f50fc92cdc5c5b5a67":[1,0,11,2,3],
-"class_qt_web_kit_1_1_q_web_element_collection.html#a8395edb41ed98a6de7d65e16f256b6ba":[1,0,11,2,17],
 "class_qt_web_kit_1_1_q_web_element_collection.html#a882fc0ab843c795f0bacf98661b051c1":[1,0,11,2,18],
-"class_qt_web_kit_1_1_q_web_element_collection.html#a8bf12ff0f07e6cd1aa12fbcc12907619":[1,0,11,2,11],
-"class_qt_web_kit_1_1_q_web_element_collection.html#a94debf33566cf2d7e1d631706c257dc2":[1,0,11,2,13],
+"class_qt_web_kit_1_1_q_web_element_collection.html#a8bf12ff0f07e6cd1aa12fbcc12907619":[1,0,11,2,12],
+"class_qt_web_kit_1_1_q_web_element_collection.html#a94debf33566cf2d7e1d631706c257dc2":[1,0,11,2,14],
 "class_qt_web_kit_1_1_q_web_element_collection.html#a96eb323ae7c775cf0d730bcfec69fb80":[1,0,11,2,6],
-"class_qt_web_kit_1_1_q_web_element_collection.html#aae7047625e0cd54bc59925806f127c96":[1,0,11,2,15],
-"class_qt_web_kit_1_1_q_web_element_collection.html#ab08038922b3eb9647afabc656b1e6f8c":[1,0,11,2,14],
+"class_qt_web_kit_1_1_q_web_element_collection.html#aae7047625e0cd54bc59925806f127c96":[1,0,11,2,16],
+"class_qt_web_kit_1_1_q_web_element_collection.html#aafe89c8b97ca471a71184048aa09743e":[1,0,11,2,11],
+"class_qt_web_kit_1_1_q_web_element_collection.html#ab08038922b3eb9647afabc656b1e6f8c":[1,0,11,2,15],
 "class_qt_web_kit_1_1_q_web_element_collection.html#acb9281be8926dc875cacc03bd7c3071f":[1,0,11,2,10],
 "class_qt_web_kit_1_1_q_web_element_collection.html#acc0e8a7d538adad1266522cd90cb288c":[1,0,11,2,8],
 "class_qt_web_kit_1_1_q_web_element_collection.html#acff94e61dd67da486d30014b68084db0":[1,0,11,2,5],
-"class_qt_web_kit_1_1_q_web_element_collection.html#ad07b474f1969ece0a64457b21d681b7b":[1,0,11,2,16],
+"class_qt_web_kit_1_1_q_web_element_collection.html#ad07b474f1969ece0a64457b21d681b7b":[1,0,11,2,17],
 "class_qt_web_kit_1_1_q_web_element_collection.html#adc53aac6f9e442fc2971f330787d2c12":[1,0,11,2,20],
 "class_qt_web_kit_1_1_q_web_element_collection.html#af1b9ff9cda49fe73aa89f19777df643c":[1,0,11,2,2],
 "class_qt_web_kit_1_1_q_web_element_collection_1_1const__iterator.html":[1,0,11,2,0],
@@ -91,11 +97,11 @@ var NAVTREEINDEX99 =
 "class_qt_web_kit_1_1_q_web_frame.html#a9f010526c7e20c2c22575908bae01f9d":[1,0,11,3,18],
 "class_qt_web_kit_1_1_q_web_frame.html#aa06d0ab5f75e1f5267ff8b092e1d3005":[1,0,11,3,45],
 "class_qt_web_kit_1_1_q_web_frame.html#aa97f48b5d15c22599326e1bb2a6e87d2":[1,0,11,3,28],
-"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aef":[1,0,11,3,0,0],
-"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aef":[1,0,11,3,0,1],
-"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aef":[1,0,11,3,0,2],
 "class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aef":[1,0,11,3,0],
-"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aef":[1,0,11,3,0,3],
+"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aefa57a49e26932713b38b0b59d8c3e5a89b":[1,0,11,3,0,1],
+"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aefa7aa93c92446df3b5771f6595de49c3d5":[1,0,11,3,0,3],
+"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aefac0e05d086007b1cc1b9758f3e7b8f1ac":[1,0,11,3,0,2],
+"class_qt_web_kit_1_1_q_web_frame.html#aab1adb11aed9ffd906e569d2e6d87aefaf752e89e15430e7c261c121d0b8a94dc":[1,0,11,3,0,0],
 "class_qt_web_kit_1_1_q_web_frame.html#ab24be600e23fa06c4ab42497d6238dbe":[1,0,11,3,68],
 "class_qt_web_kit_1_1_q_web_frame.html#ab48c1cac5b67d26d1171279a3a25e22d":[1,0,11,3,8],
 "class_qt_web_kit_1_1_q_web_frame.html#ab4be77836d7b0569fa3e0b80f03046d0":[1,0,11,3,74],
@@ -215,8 +221,8 @@ var NAVTREEINDEX99 =
 "class_qt_web_kit_1_1_q_web_page.html#a019e5b72713412931d83be89b97dfb4d":[1,0,11,9,119],
 "class_qt_web_kit_1_1_q_web_page.html#a03263dd19dd033bf0c75321612b49788":[1,0,11,9,44],
 "class_qt_web_kit_1_1_q_web_page.html#a09ae0ddfab3e3b3c2d86d7096d8f1826":[1,0,11,9,8],
-"class_qt_web_kit_1_1_q_web_page.html#a09ae0ddfab3e3b3c2d86d7096d8f1826":[1,0,11,9,8,1],
-"class_qt_web_kit_1_1_q_web_page.html#a09ae0ddfab3e3b3c2d86d7096d8f1826":[1,0,11,9,8,0],
+"class_qt_web_kit_1_1_q_web_page.html#a09ae0ddfab3e3b3c2d86d7096d8f1826a3543ac93dbd979f7c19d132597ecc0ba":[1,0,11,9,8,0],
+"class_qt_web_kit_1_1_q_web_page.html#a09ae0ddfab3e3b3c2d86d7096d8f1826a5dc12c80df1bda01a0dcbf6ca1b3962a":[1,0,11,9,8,1],
 "class_qt_web_kit_1_1_q_web_page.html#a0b169a930bc87ccfbc159fa1ab58d688":[1,0,11,9,114],
 "class_qt_web_kit_1_1_q_web_page.html#a0c11347e640269d580b118160a01e69d":[1,0,11,9,122],
 "class_qt_web_kit_1_1_q_web_page.html#a0e82ad69a8ebba2008f8c32ee14bcacc":[1,0,11,9,93],
@@ -243,11 +249,5 @@ var NAVTREEINDEX99 =
 "class_qt_web_kit_1_1_q_web_page.html#a3b2dcd10413f478c27ef36e59d06a9d2":[1,0,11,9,47],
 "class_qt_web_kit_1_1_q_web_page.html#a401311a8ddff6a8eb1b733b0e293c707":[1,0,11,9,112],
 "class_qt_web_kit_1_1_q_web_page.html#a404d089aff043d3ffdd4178591557468":[1,0,11,9,27],
-"class_qt_web_kit_1_1_q_web_page.html#a463f6ebba53ba9ab57368179d8100fea":[1,0,11,9,50],
-"class_qt_web_kit_1_1_q_web_page.html#a477b02d272cf69430ef8f4eb22687538":[1,0,11,9,23],
-"class_qt_web_kit_1_1_q_web_page.html#a49b9e3d8e989f7530eb0dfdcfd674367":[1,0,11,9,78],
-"class_qt_web_kit_1_1_q_web_page.html#a4a696f3f1fc10da444e1ee22c9b41645":[1,0,11,9,58],
-"class_qt_web_kit_1_1_q_web_page.html#a4abad5bfd4ed45c2e54a464b98cd94a8":[1,0,11,9,46],
-"class_qt_web_kit_1_1_q_web_page.html#a4cc2186015b34a16f1121288d079eb24":[1,0,11,9,31],
-"class_qt_web_kit_1_1_q_web_page.html#a4f83686be74ad6f7dac18255dc07eb53":[1,0,11,9,49]
+"class_qt_web_kit_1_1_q_web_page.html#a463f6ebba53ba9ab57368179d8100fea":[1,0,11,9,50]
 };
